--[[
STRATEGIC TARGET STRIKE DISPATCHER by Glloq (Caucasus and Syria compatible)

The strategic target strike dispatcher mission is more kind of a template mission you can customize than a mission.
It will allow you to strike a group of scenery objets (like bridges, factories or buildings) already included in the map in circular zones you have selected (by default a single circular zone called "targetZone").
Selected targets area will be marked on the F10 minimap and the mission briefing will pop with coordinates and target list (You can ask for a summary anytime via the F10 radio menu) 

Feel free to move the zone or add more, add or change aircrafts/helicopters types or add enemy units. Don't forget to bring the heavy weapons because some targets are tough to destroy

Thanks to toutenglisse for helping me to understand how to get full SceneryObject data
Thanks to everyone behind MIST and MOOSE Frameworks that made this possible
Thanks to everyone from my virtual squadron "8TH Rapaces" for being the boldest and greatest beta testers ;-)

Using the F10 Radio Menu you will find the "Strategic targets strike" menu.
Inside it you can :
- ask for the mission briefing with target area coordinates and description of all the remaining targets to destroy
- pop a smoke (Green, orange, red or white at will)
- skip to next strategic targets. It will cancel the current strategic targets list and select after a few seconds another list of strategic targets to strike

Restrictions:
- Only work on the Caucasus and Syria map right now but there are enough debug tools to expand it to others maps
- Menu is for blue coalition by default but you can change it by calling setDispatcherForBlueCoalition() or setDispatcherForRedCoalition() before the startDispatcher function
- Once the lua file loaded you can use addCircularZone(zoneName) to add zones where you want to scan for "strategic targets" to strike. Then use startDispatcher() to launch the selection.
It should be done in mission start due to how long the process take
- Obviously the bigger the zone, the more time it will take to evaluate "strategic targets group" when a new one is requested
- You can choose to strike only one scenery object of a time instead of a group around X meters from the first one to bypass the freeze at strategic target selection.
For this you need to comment the call to getLocalStrategicTargetsInArea(strategicTarget, 1000). checkForAdditionalStrategicTargetsInArea method is then useless too.


Known bugs:
- {typeName = "PLATFORMA_AKACYA", description ="Railway wagon with artillery tank"}, --Railway wagon with artillery tank on it //FIXME WHY OTHER RAILWAY WAGON ARE NOT FOUND ? DCS Caucasus Issue ?
- Scenery objetcs wih null typeName on Caucasus

Scenery objects are grouped by custom theme and you can choose to pick from one or not in insertFoundUnitInStrategicTargetListIfNeeded method. Choose wisely and don't commit war crimes !

Scenery objects are only added in the list of available strategic targets only if they are valid targets.
A scenery object has the validTarget property set to true if visible, can be destroyed, and visually identify it among others.

If I keep improving this code next features would be adding defenses to target area (depending strategic value?) but don't expect anything before at least "Two weeks" 
--]]

--Use for faster debug of scenery objects not in a category yet
local targetDebugging = false

local zoneList = {}

--UTIL TOOLS START
function tprint (tbl, indent)
  if not indent then indent = 0 end
  local toprint = string.rep(" ", indent) .. "{\r\n"
  indent = indent + 2
  if tbl then
    for k, v in pairs(tbl) do
      toprint = toprint .. string.rep(" ", indent)
      if (type(k) == "number") then
        toprint = toprint .. "[" .. k .. "] = "
      elseif (type(k) == "string") then
        toprint = toprint  .. k ..  "= "   
      end
      if (type(v) == "number") then
        toprint = toprint .. v .. ",\r\n"
      elseif (type(v) == "string") then
        toprint = toprint .. "\"" .. v .. "\",\r\n"
      elseif (type(v) == "table") then
        toprint = toprint .. tprint(v, indent + 2) .. ",\r\n"
      else
        toprint = toprint .. "\"" .. tostring(v) .. "\",\r\n"
      end
    end
  end
  toprint = toprint .. string.rep(" ", indent-2) .. "}"
  return toprint
end

local function has_value (tab, val)
    for index, value in ipairs(tab) do
        if value == val then
            return true
        end
    end

    return false
end

local function has_typeName (tab, val)
    for index, value in ipairs(tab) do
        if value.typeName == val then
            return true
        end
    end

    return false
end

local function isValidTarget(tab, val)
    for index, value in ipairs(tab) do
        if value.typeName == val then
            if value.validTarget and value.validTarget == true then        
              return true
            end
        end
    end

    return false
end

function tablefind(tab,el)
  for index, value in pairs(tab) do
    if value == el then
      return index
    end
  end
end

function insertInTableIfNew(tab, val)
  if not has_value(tab, val) then
    table.insert(tab, val)
  else
    trigger.action.outText("insertInTableIfNew - existing element", 20)
    env.info("insertInTableIfNew - existing element")
  end
end

function insertInStrategicTargetList(val)
  if not targetDebugging then
    insertInTableIfNew(strategicTargetList, val)
  end
end

function forceInsertInStrategicTargetList(val)
  insertInTableIfNew(strategicTargetList, val)
end

function getCoordinatesSTR(decLat, decLong)
  local lat1, latF1 = math.modf(decLat)
  local latF2, latF3 = math.modf(latF1 * 60)
  
  local long1, longF1 = math.modf(decLong)
  local longF2, longF3 = math.modf(longF1 * 60)
  return {lat = string.format("%02d", lat1) .. "d " .. string.format("%02d",latF2) .. "' " .. string.format("%02d",math.floor(latF3 * 60)) .. "''N", 
          long = string.format("%02d", long1) .. "d " .. string.format("%02d",longF2) .. "' " .. string.format("%02d",math.floor(longF3 * 60)) .. "''E"}
  
end

function spawnInfantrySquad(position)
  --trigger.action.outText("createAllyTroops", 3)    
        
  local groupUnits =
  {
    [1] = {   
      ["name"] =  "Infantry-1",  
      ["unitId"] = math.random(9999,99999),                                    
      ["type"] = "Soldier M249",                                
      ["skill"] = "High", 
      ["x"] = position.x,                                   
      ["y"] = position.z,  
      ["alt"] = 0,
      --["alt_type"] = "RADIO",
      ["heading"] = math.random(359),                                                                    
      ["speed"] = 0,      
      ["psi"] = 0,               
    }
  }

  local group = {
      ["name"] =  "Test-" .. math.random(9999,99999),
      ["groupId"] = 500 + math.random(1, 1000),
      ["x"] = x,
      ["y"] = z,
      ["start_time"] = 0,
      ["communication"] = true,
      ["frequency"] = 124,
      ["modulation"] = 0,
      ["tasks"] = {},
      ["task"] = "",
      ["uncontrolled"] = false,
      ["hidden"] = false,
      ["units"] = groupUnits,
    }

  coalition.addGroup(country.id.USA, Group.Category.GROUND, group)             
  --local group = Group.getByName(groupName) -- for some stupid reason the coalition.addgroup doesn't return the created group object. You have to find it afterwards.
  --return group
end

function explodeThis(coordinates)
  trigger.action.explosion(coordinates, 5000)
end

function testGroup(groupName)
  env.info("testGroup " .. groupName)
  local group = GROUP:FindByName(groupName)
  local infantrySpawn = false
  if group then
    local units = group:GetUnits()
    for i,unit in ipairs(units) do
      if unit then
        local unitWP = {x = unit.x, y = unit.y , z = unit.z}
        if not infantrySpawn then
          spawnInfantrySquad(unitWP)
          infantrySpawn = true
        end
        unit:Explode(1000,10)
        --timer.scheduleFunction(explodeThis, unitWP, timer.getTime() + 10)
      else
        env.info( unit.name .. " not found")
      end
    end
  else
    env.info(groupName .. " not found")
  end
  --local groupWP = {x = group:getPosition().p.x, y = group:getPosition().p.y , z = group:getPosition().p.z}
  --spawnInfantrySquad(groupWP)
  --timer.scheduleFunction(explodeThis, groupWP, timer.getTime() + 10)
end

function testUnit(unitName)
  env.info("testUnit " .. unitName)
  local myUnit = UNIT:FindByName(unitName)
  if myUnit then    
    local unitWP = {x = myUnit.x, y = myUnit.y , z = myUnit.z}
    --spawnInfantrySquad(unitWP)
    timer.scheduleFunction(explodeThis, unitWP, timer.getTime() + 10)
  else
    env.info(unitName .. " not found")
  end
end

function checkBuildingDestroyed(triggerZoneName, flagValue)
  mist.flagFunc.mapobjs_dead_zones{ zones = {triggerZoneName}, flag = flagValue }
end

function isGroupNameDestroyed(groupName)
  local group = Group.getByName(groupName)
  if group == nil then
    --trigger.action.outText("isGroupNameDestroyed true", 20)
    --env.info("isGroupNameDestroyed true")
    return true
  --elseif group:getUnit(0) == nil then
  --  return true
  else
    local units = group:getUnits()
    for i,unit in ipairs(units) do
      if unit ~= nil then
        --trigger.action.outText("isGroupNameDestroyed false", 20)
        --env.info("isGroupNameDestroyed false")
        return false
      end
    end
    
    --trigger.action.outText("isGroupNameDestroyed true", 20)
    --env.info("isGroupNameDestroyed true")
    return true
  end
end

--UTIL TOOLS END

--SMOKE TOOLS START
-- Lock and Unlock functions to control when each color of smoke is available
local TargetSmokeGreenLockout = 0
local TargetSmokeOrangeLockout = 0
local TargetSmokeRedLockout = 0
local TargetSmokeBlueLockout = 0
local TargetSmokeWhiteLockout = 0

function TargetSmokeGreenLock()
  TargetSmokeGreenLockout = 1
end

function TargetSmokeGreenUnlock()
  TargetSmokeGreenLockout = 0
end

function TargetSmokeOrangeLock()
  TargetSmokeOrangeLockout = 1
end

function TargetSmokeOrangeUnlock()
  TargetSmokeOrangeLockout = 0
end

function TargetSmokeRedLock()
  TargetSmokeRedLockout = 1
end

function TargetSmokeRedUnlock()
  TargetSmokeRedLockout = 0
end

function TargetSmokeBlueLock()
  TargetSmokeBlueLockout = 1
end

function TargetSmokeBlueUnlock()
  TargetSmokeBlueLockout = 0
end

function TargetSmokeWhiteLock()
  TargetSmokeWhiteLockout = 1
end

function TargetSmokeWhiteUnlock()
  TargetSmokeWhiteLockout = 0
end

function smokeStrategicTargetsStrikeLocation(smokeColor)
  local color
  local smokeLaunched = false
  
  if(smokeColor == SMOKECOLOR.Red) then
    color = "Red"
    if ( TargetSmokeRedLockout == 0 ) then
      smokeLaunched = true
      TargetSmokeRedLock()
      timer.scheduleFunction(TargetSmokeRedUnlock, 53, timer.getTime() + 150)
    end
  elseif(smokeColor == SMOKECOLOR.Blue) then
    color = "Blue"
    if ( TargetSmokeBlueLockout == 0 ) then
      smokeLaunched = true
      TargetSmokeBlueLock()
      timer.scheduleFunction(TargetSmokeBlueUnlock, 53, timer.getTime() + 150)
    end
  elseif(smokeColor == SMOKECOLOR.Green) then
    color = "Green"
    if ( TargetSmokeGreenLockout == 0 ) then
      smokeLaunched = true
      TargetSmokeGreenLock()
      timer.scheduleFunction(TargetSmokeGreenUnlock, 53, timer.getTime() + 150)
    end
  elseif(smokeColor == SMOKECOLOR.White) then
    color = "White"
    if ( TargetSmokeWhiteLockout == 0 ) then
      smokeLaunched = true
      TargetSmokeWhiteLock()
      timer.scheduleFunction(TargetSmokeWhiteUnlock, 53, timer.getTime() + 150)
    end
  elseif(smokeColor == SMOKECOLOR.Orange) then
    color = "Orange"
    if ( TargetSmokeOrangeLockout == 0 ) then
      smokeLaunched = true
      TargetSmokeOrangeLock()
      timer.scheduleFunction(TargetSmokeOrangeUnlock, 53, timer.getTime() + 150)
    end
  end
  
  if smokeLaunched then
    local targetAreaInfo = getTargetAreaInfo(false)
    local smokeCoordinate = COORDINATE:NewFromVec3(targetAreaInfo.targetAreaWP)
    smokeCoordinate:Smoke( smokeColor )
    trigger.action.outSoundForCoalition(dispatcherCoalition, 'Target Smoke.ogg')
    trigger.action.outTextForCoalition(dispatcherCoalition, "Target Has Been Marked With " .. color .. " Smoke", 15)
  else
    trigger.action.outTextForCoalition(dispatcherCoalition, color .. " Smoke Currently Unavailable - Shells Are Being Reloaded", 15)
  end
end
--SMOKE TOOLS END

--STRATEGIC TARGET START
notFoundTypeNameList = {}
strategicTargetList = {}
strategicTargetCount = 1


--[[
Object properties:
  typeName : scenery object in-game typename
  description: small scenery object description to visual identify it among others 
  validTarget: true if visible, can be destroyed, and visually identify it among others. If false or not set will not be added to strategicTargetList
-- ]]

CAUCASUS_AIRPORT_SMALL_OBJECTS_TYPENAMES = {
  {typeName = "AIRBASE_AIRPORT_TBILISI_BLOCK_01", description ="Airport object"}, --Small prefabricated block / building
  {typeName = "AIRBASE_AIRPORT_TBILISI_VISHKA_01", description ="Airport object"}, --Small wood approach watchtower
  {typeName = "AIRBASE_AIRPORT_TBILISI_VISHKA_01_CRASH", description ="Airport object"}, --Destroyed small wood approach watchtower
  {typeName = "AIRBASE_METEO_TBILISI_01", description ="Airport object"}, --Small two floor tower with meteo radar on top
  {typeName = "AIRBASE_METEO_TBILISI_02", description ="Airport object"}, --Meteo radar
  {typeName = "AIRBASE_TBILISI_TENT", description ="White cylindrical tent"}, --White cylindrical tent - only on some airbases
  {typeName = "AIRBASE_VOR", description ="Airport object"}, --Cylindrical small VOR antenna
  {typeName = "A_BLOCK", description ="Taxiway Panel"}, --Taxiway Panel info with A letter
  {typeName = "A_FRWD", description ="Taxiway Panel"}, --Taxiway Panel info with A and forward sign
  {typeName = "A_LEFT", description ="Taxiway Panel"}, --Taxiway Panel info with A and Left sign
  {typeName = "A_RIGHT", description ="Taxiway Panel"}, --Taxiway Panel info with A and Right sign
  {typeName = "B_BLOCK", description ="Taxiway Panel"}, --Taxiway Panel info with B letter
  {typeName = "B_FRWD", description ="Taxiway Panel"}, --Taxiway Panel info with B and forward sign
  {typeName = "B_LEFT", description ="Taxiway Panel"}, --Taxiway Panel info with B and Left sign
  {typeName = "B_RIGHT", description ="Taxiway Panel"}, --Taxiway Panel info with B and Right sign
  {typeName = "C_BLOCK", description ="Taxiway Panel"}, --Taxiway Panel info with C letter
  {typeName = "C_LEFT", description ="Taxiway Panel"}, --Taxiway Panel info with C and Left sign
  {typeName = "C_RIGHT", description ="Taxiway Panel"}, --Taxiway Panel info with C and Right sign
  {typeName = "D_BLOCK", description ="Taxiway Panel"}, --Taxiway Panel info with D letter
  {typeName = "D_FRWD", description ="Taxiway Panel"}, --Taxiway Panel info with D and forward sign
  {typeName = "D_LEFT", description ="Taxiway Panel"}, --Taxiway Panel info with D and Left sign
  {typeName = "D_RIGHT", description ="Taxiway Panel"}, --Taxiway Panel info with D and Right sign
  {typeName = "E_BLOCK", description ="Taxiway Panel"}, --Taxiway Panel info with E letter
  {typeName = "E_FRWD", description ="Taxiway Panel"}, --Taxiway Panel info with E and forward sign
  {typeName = "E_LEFT", description ="Taxiway Panel"}, --Taxiway Panel info with E and Left sign
  {typeName = "E_RIGHT", description ="Taxiway Panel"}, --Taxiway Panel info with E and Right sign
  {typeName = "F_BLOCK", description ="Taxiway Panel"}, --Taxiway Panel info with F letter
  {typeName = "F_LEFT", description ="Taxiway Panel"}, --Taxiway Panel info with F and Left sign
  {typeName = "F_RIGHT", description ="Taxiway Panel"}, --Taxiway Panel info with F and Right sign
  {typeName = "G_BLOCK", description ="Taxiway Panel"}, --Taxiway Panel info with G letter
  {typeName = "G_LEFT", description ="Taxiway Panel"}, --Taxiway Panel info with G and Left sign
  {typeName = "H_BLOCK", description ="Taxiway Panel"}, --Taxiway Panel info with H letter
  {typeName = "H_LEFT", description ="Taxiway Panel"}, --Taxiway Panel info with H and Left sign
  {typeName = "COURSE_27_09", description ="Taxiway Panel"}, --Taxiway Panel with runway course
  {typeName = "COURSE_31L", description ="Taxiway Panel"}, --Taxiway Panel with runway course
  {typeName = "COURSE_31L_13R", description ="Taxiway Panel"}, --Taxiway Panel with runway course
  {typeName = "DIRECTIONAL_APPROACH_ELEVATED_GREEN", description ="Landing light (green)"}, --
  {typeName = "DIRECTIONAL_APPROACH_LIGHTS", description ="Landing light"}, --
  {typeName = "DIRECTIONAL_APPROACH_LIGHTS_GROUP", description ="Landing light"}, --
  {typeName = "DIRECTIONAL_APPROACH_LIGHTS_RED", description ="Landing light (red)"}, --
  {typeName = "IN_PAVEMENT_BI_DERECTIONAL_WHITE_ORANGE", description ="Landing light (white orange)"}, --
  {typeName = "IN_PAVEMENT_BI_DERECTIONAL_WHITE_WHITE", description ="Landing light (white)"}, --Landing light
  {typeName = "GAZ-66_SEARCHLIGHT", description ="GAZ-66 truck with a searchlight"}, --Truck that light the runway on airport
  {typeName = "OHR-VYSHKA", description ="Wood watchtower"}, --Wood watchtower
  {typeName = "PAPISYSTEM_1", description ="Landing light"}, --Runway axis landing light system
  {typeName = "PAPISYSTEM_2", description ="Landing light"}, --Runway axis landing light system
  {typeName = "PAPISYSTEM_3", description ="Landing light"}, --Runway axis landing light system
  {typeName = "PAPISYSTEM_4", description ="Landing light"}, --Runway axis landing light system
  {typeName = "PAR_AGREGATNAYA", description ="Airport object"}, --Very small warehouse on radio transmission system
  {typeName = "PAR_APPARATNAYA", description ="Airport object"}, --Very small warehouse on close ILS approach
  {typeName = "PAR_APPARATNAYA_20", description ="Airport object"}, --Very small warehouse on far ILS approach
  {typeName = "PAR_GSM", description ="Airport object"}, --Small FUEL DEPOT on ILS approach or airport
  {typeName = "RSBN", description ="RSBN truck with antenna"}, --RSBN truck with antenna
  {typeName = "RSBN_GENER", description ="RSBN Generator (Small)"}, --Small generator for RSBN station
  {typeName = "RSBN_GSM", description ="RSBN Fuel storage (small)"}, --Small fuel storage for RSBN station
  {typeName = "RSP-7", description ="RSP-7 Radar truck"}, --Radar Truck on airport
  {typeName = "RSP_DRL-7", description ="RSP DRL-7 antenna"}, --Small radar antenna on a trolley in airport
  {typeName = "RSP_ESD-20", description ="RSP Generator"}, --Small generator on wheels in airports
  {typeName = "RSP_PELENG", description ="RSP Radio antenna (Small)"}, --Very small radio antenna
  {typeName = "RSP_RADIO", description ="RSP Radio antenna (Very small)"}, --Very small radio antenna close to airport
  {typeName = "PRW-11", description ="PRW-11 Radar antenna on a trolley"}, --Radar antenna on a trolley in airport
  {typeName = "RLS-37", description ="RLS-37 Dug radar"}, --Radar on airfield dug in the ground
  {typeName = "SARAY-D_NEW", description ="Warehouse/Building (Very small)"}, --Small one floor building on airport
  {typeName = "SARAY-F_NEW", description ="Warehouse/Building (Very very small)"}, --Small one floor building on airport - Security check maybe
  {typeName = "SKLADIK", description ="Open air ammo depot (Very small)", validTarget=true}, --Small open air ammo depot on airport - Big boom XD
  {typeName = "TAXIWAY_LIGHT_BLUE", description ="Airport object"}, --??
}

CAUCASUS_AIRPORT_STRATEGIC_TARGETS_TYPENAMES = {
  {typeName = "AIR_CLOSEDGUARDHOUSE_03A", description ="Aircraft shelter", validTarget=true}, --big aircraft shelter with tags on it and grass above
  {typeName = "AIRBASE_AIRPORT_KDP_TBILISI", description ="Airport tower", validTarget=true}, --Tbilisi small approach / runway tower
  {typeName = "AIRBASE_AIRPORTOLD_TBILISI", description ="Airport terminal"}, --Tbilisi airport terminal
  {typeName = "AIRBASE_AIRPORT_TBILISI_01", description ="Airport railway station"}, --Tbilisi airport railway station
  {typeName = "AIRBASE_AIRPORT_TBILISI_03", description ="Airport terminal"}, --Tbilisi airport terminal
  {typeName = "AIRBASE_AIRPORT_TBILISI_BIG", description ="Airport terminal"}, --Tbilisi airport terminal
  {typeName = "AIRBASE_AIRPORT_TBILISI_CHECKPOINT_01", description ="Airport terminal"}, --Tbilisi airport terminal
  {typeName = "AIRBASE_HUNGAR", description ="Airport hangar", validTarget=true}, --
  {typeName = "AIRBASE_KDP_TBILISI", description ="Airport tower", validTarget=true}, --Tbilisi small approach / runway tower
  {typeName = "AIRBASE_KDP2_TBILISI", description ="Airport tower", validTarget=true}, --Tbilisi medium approach / runway tower
  {typeName = "AIRPORT", description ="Airport terminal"}, --Airport terminal
  {typeName = "AIRPORT_BABUSHARA_NEW", description ="Airport terminal"}, --Sukhumi-Babushara airport terminal - Only there
  {typeName = "AIRPORT_BABUSHARA_OLD", description ="Airport terminal"}, --Sukhumi-Babushara airport terminal - Only there
  {typeName = "BATUMI_HANGAR_MED", description ="Cylindrical airport hangar / warehouse", validTarget=true}, --Cylindrical wrinkled airport hangar / warehouse
  {typeName = "BATUMI_HANGAR_SMALL", description ="Cylindrical airport hangar / warehouse (Small)", validTarget=true}, --Cylindrical wrinkled airport hangar / warehouse (Small) - Only there?
  {typeName = "BATUMI_KDP", description ="Airport tower", validTarget=true}, --Batumi medium approach / runway tower
  {typeName = "BATUMI_TERMINAL", description ="Airport terminal"}, --Batumi terminal
  {typeName = "BESLAN_VLADIKAVKAZ", description ="Airport terminal"}, --Beslan terminal
  {typeName = "F_KORPUS_B", description ="Batumi airport 4 floor Building"}, --Batumi airport 4 floor building
  {typeName = "INZ", description ="Airport tower", validTarget=true}, --Small approach / runway control tower
  {typeName = "INZ_BIG", description ="Airport tower", validTarget=true}, --Big approach / runway control tower
  {typeName = "KDP", description ="Airport tower", validTarget=true}, --Medium approach / runway tower
  {typeName = "KDP_BIG", description ="Airport tower", validTarget=true}, --Big approach / runway tower
  {typeName = "LOKATOR", description ="Airport locator building"}, --Locator building and semi-spherical shaped dome
  {typeName = "TERMINAL_1", description ="Airport terminal"}, --Airport terminal
  {typeName = "UKRYTIE", description ="Aircraft shelter", validTarget=true}, --Aircraft shelter
  {typeName = "UKRYTIE_B_NEW", description ="Airport ammo and fuel shelter", validTarget=true}, --Small V-shape shelter not suitable for aircraft or vehicle / Airport shelter close to ammo and fuel storage
  {typeName = "WAREHOUSE_BABUSHARA_01", description ="Airport Y-shaped wood warehouse", validTarget=true}, --Sukhumi-Babushara airport Y-shaped wood warehouse - Only there
}

CAUCASUS_PORT_STRATEGIC_TARGETS_TYPENAMES = {
  {typeName = "DOK_S_NEW", description ="Port ship building/reparation floating dock", validTarget=true}, --Port ship building/reparation floating dock
}

CAUCASUS_OFFSHORE_OIL_RIG_TYPENAMES = {
  {typeName = "MBY_13", description ="Offshore oil rig platform", validTarget=true}, --Offshore oil rig platform with helipad and two derricks
  {typeName = "MBY_15", description ="Offshore oil rig platform", validTarget=true}, --Offshore oil rig platform with helipad
  --Oil rig platform accessories below not recommended as target since no dead event if the oil rig platform is sinked before them being destroyed
  {typeName = "MBY_CRANE_02", description ="Crane"}, --Crane on oil rig platform / ship dock
  {typeName = "MBY_DERRICK_02", description ="Derrick"}, --Derrick on oil rig platform
  {typeName = "MBY13_HELIPAD", description ="Helipad"}, --Helipad on "MBY_13" platform
  {typeName = "MBY15_HELIPAD", description ="Helipad"}, --Helipad on "MBY_15" platform - indestructible ?
  {typeName = "MBY_PLATFORM_02", description ="Oil rig platform"}, --Platform on which the derrick is set on the oil rig platform
  {typeName = "MBY_SMALLLAMP_01", description ="Helipad Lamp (Very Small)"}, --Very small lamp lighting the helipad on the oil rig platform - indestructible
  {typeName = "MBY_TANK_02", description ="Tanks"}, --Tank between the MBY_PLATFORM_02 and MBY_DERRICK_02 - Not only use on oil rig platform
}

CAUCASUS_RAILWAY_STRATEGIC_TARGETS_TYPENAMES = {
  {typeName = "VOK_SIM_A", description ="Railway station part", validTarget=true}, --Big krasnodar-center railway station part
  {typeName = "VOK_SIM_B", description ="Railway station part", validTarget=true}, --Big krasnodar-center railway station part
  {typeName = "VOK_SIM_C", description ="Railway station part", validTarget=true}, --Big krasnodar-center railway station part
  {typeName = "VOK_SIM_D", description ="Railway station part", validTarget=true}, --Big krasnodar-center railway station tall part
  {typeName = "VOK_SIM_E", description ="Railway station part", validTarget=true}, --Big krasnodar-center railway station small part
  {typeName = "VOKZ_A", description ="Railway station", validTarget=true}, --Medium railway station tall one floor building
  {typeName = "VOKZ_BIG", description ="Railway station (Big)", validTarget=true}, --Big Railway station
  {typeName = "PLATFORMA_AKACYA", description ="Railway wagon with artillery tank"}, --Railway wagon with artillery tank on it //FIXME WHY OTHER RAILWAY WAGON ARE NOT FOUND ?
}

CAUCASUS_RAILWAY_BRIDGES_TYPENAMES = {
  {typeName = "MOST-FERMA", description ="Railway bridge", validTarget=true}, --Railway bridge
  {typeName = "MOST-FERMA-A", description ="Railway bridge (Small)", validTarget=true}, --Small Railway bridge
  {typeName = "MST-FERMA", description ="Railway bridge (Small)", validTarget=true}, --Small Railway bridge
}


CAUCASUS_ROAD_BRIDGES_TYPENAMES = 
{
  {typeName = "MOST(ROAD)BIG", description ="Road bridge section", validTarget=true}, --Big road bridge section
  {typeName = "MOST(ROAD)BIG_END", description ="Road bridge end section ", validTarget=true}, --Big road bridge end section close to ground
  {typeName = "MOST(ROAD)SMALL", description ="Road bridge (small)", validTarget=true}, --Small road bridge
  {typeName = "MOST(ROAD)SMALL-A", description ="Road bridge", validTarget=true}, --Road bridge section
  {typeName = "MOSTIK", description ="Road bridge (small)", validTarget=true}, --Small road bridge
  {typeName = "MOSTIK-A", description ="Road bridge (small)", validTarget=true}, --Small road bridge
  {typeName = "MST(ROAD)SMALL", description ="Road bridge (small)", validTarget=true}, --Road bridge
  {typeName = "MSTIK", description ="Road bridge (small)", validTarget=true}, --Small road bridge
  {typeName = "ONE_PIECE_BRIDGE", description ="Road bridge (long)", validTarget=true}, --Long road bridge
  {typeName = "ONE_PIECE_BRIDGE02", description ="Road bridge (very long)", validTarget=true}, --Very long bridge
}


CAUCASUS_TANKS_TYPENAMES = {
  {typeName = "AIRBASE_BARRELS_01", description ="3 horizontal tanks", validTarget=true}, --Three horizontal cistern stuck together
  {typeName = "AIRBASE_BARRELS_02", description ="3 horizontal tanks", validTarget=true}, --Three horizontal cistern stuck together
  {typeName = "AIRBASE_TBILISI_TANK_01", description ="3 floor tall tank", validTarget=true}, --2/3 floor tank
  {typeName = "AIRBASE_TBILISI_TANK_02", description ="2 floor tall tank", validTarget=true}, --2 floor tank
  {typeName = "BAK_NEW", description ="Cylindric tank", validTarget=true}, --Medium cylindric tank
  {typeName = "HIM_BAK_A_NEW", description ="Cylindric tank", validTarget=true}, --Medium cylindric tank
  {typeName = "HIM_BAK_B", description ="Cylindric tank (Very tall)", validTarget=true}, --Very tall cistern / grain silo
  {typeName = "HIM_BAK_BIG", description ="Cylindric tank (Very tall and big)", validTarget=true}, --Very tall and big cistern / grain silo
  {typeName = "HIM_BAK_C", description ="Tank (Very small)"}, --Very small tank
  {typeName = "TOPLIVO-BAK_NEW", description ="Tank (Half buried)", validTarget=true}, --half buried cistern
  {typeName = "TUAPSE_PETROLEUM_TANKAGE", description ="Spherical tank", validTarget=true}, --Spherical tank
}

CAUCASUS_VERY_SMALL_WAREHOUSES_TYPENAMES = {
  {typeName = "GARAGH-SMALL-A_NEW", description ="Garage / Warehouse (Very small)"}, --Small one floor garage / warehouse
  {typeName = "GARAGH-SMALL-B_NEW", description ="Garage / Warehouse (Very small)"}, --Small one floor garage / warehouse
  {typeName = "HOZDOMIK3_NEW", description ="Warehouse (Very small)"}, --Very very small one floor warehouse
}


CAUCASUS_SMALL_WAREHOUSES_TYPENAMES = {
  {typeName = "HOZDOMIK1_NEW", description ="Warehouse with windows (Long and small)"}, --Small and long one floor warehouse with windows
  {typeName = "HOZDOMIK2_NEW", description ="Warehouse with windows (Small)"}, --Small one floor warehouse with windows
}

CAUCASUS_MEDIUM_WAREHOUSES_TYPENAMES = {
  {typeName = "AIRBASE_AIRPORT_TBILISI_HANGAR_01", description ="Hangar (Long)", validTarget=true}, --Long hangar
  {typeName = "ANGAR_A_NEW", description ="Hangar (Long and small)", validTarget=true}, --Long and small height hangar
  {typeName = "ANGAR_B_NEW", description ="Hangar", validTarget=true}, --hangar
  {typeName = "CEH_ANG_A_NEW", description ="Cylindric Hangar (Big)", validTarget=true}, --Big 1 floor cylindric hangar
  {typeName = "F_SKLAD", description ="Warehouse", validTarget=true}, --Warehouse
  {typeName = "GARAGE_A_NEW", description ="Garage / warehouse", validTarget=true}, --Medium size one floor garage / warehouse
  {typeName = "GARAGE_B_NEW", description ="Garage / warehouse", validTarget=true}, --Medium size tall one floor garage / warehouse
  {typeName = "R_VOK_SD_NEW", description ="Two floors building / warehouse with windows"}, --Small two floor building (often on airport or railway station) -Looks to much like a civilian building
  {typeName = "SKLAD_NEW", description ="Warehouse", validTarget=true}, --Warehouse
  {typeName = "STOLOVAYA1", description ="Canteen / warehouse (Long)", validTarget=true}, --Long one floor flat roof canteen / warehouse
  {typeName = "STOLOVAYA_NEW", description ="Canteen / warehouse (Long)", validTarget=true}, --Long one floor flat roof canteen / warehouse
}

CAUCASUS_BIG_WAREHOUSES_TYPENAMES = {
  {typeName = "AIRBASE_AIRPORT_TBILISI_03_02", description ="Warehouse (Long)", validTarget=true}, --Long warehouse
  {typeName = "CEH_A", description ="Hangar / Warehouse with big windows around and on top (Long and tall)", validTarget=true}, --Big 3 floor hangar with big windows around and on top
  {typeName = "CEH_ANG_B", description ="4 floor Hangar with big windows around (Big)", validTarget=true}, --Big 4 floor hangar with big windows around
  {typeName = "CEH_ANG_C", description ="3 floor Hangar with big windows around and on top (Big)", validTarget=true}, --Big 3 floor hangar with big windows around and on top
  {typeName = "CEH_B", description ="3 floor Hangar with big windows (Big)", validTarget=true}, --Big 3 floor hangar with big windows
  {typeName = "CEH_B1", description ="3 floor Hangar with big windows around and on top (Big)", validTarget=true}, --Big 3 floor hangar with big windows around and on top
  {typeName = "CEH_C", description ="3 floor Hangar with big windows (Big)", validTarget=true}, --Big 3 floor hangar with big windows
  {typeName = "CEH_D", description ="3 floor Hangar with big windows (Big)", validTarget=true}, --Big 3 floor hangar with big windows
  {typeName = "FERMA_A_NEW", description ="Hangar (Very long)", validTarget=true}, --Very long one floor hangar / warehouse
  {typeName = "FERMA_B_NEW", description ="Hangar (Very long)", validTarget=true}, --Very long one floor hangar / warehouse
  {typeName = "TECH_NEW", description ="Hangar / Warehouse (Very very Big and Tall)", validTarget=true}, --Very very Big and tall hangar / Warehouse
}


CAUCASUS_HOUSES_TYPENAMES = {
  {typeName = "AVIASHTAB_NEW", description ="2 floor house (Big)"}, --Medium/Big two floor house
  {typeName = "DOM2A", description ="2 floor house (Big)"}, --Two floor big house
  {typeName = "DOM2C_NEW", description ="2 floor house (Big)"}, --Two floor big house
  {typeName = "DOMIK1A_NEW", description ="2 floor house with attached small warehouse (Very small)"}, --Very small two floor house with linked small warehouse
  {typeName = "DOMIK1B_NEW", description ="1 floor house"}, --One floor house
  {typeName = "DOMIK1C", description ="2 floor house (Small)"}, --Small two floor house
  {typeName = "DOMIK1D", description ="2 floor house (Small)"}, --Small two floor house
  {typeName = "HOME1UG_A", description ="1 floor L-shaped house"}, --One floor L-shaped house
  {typeName = "HOME1UG_B", description ="1 floor L-shaped house"}, --One floor L-shaped house
  {typeName = "HOME1UG_C", description ="1 floor L-shaped house"}, --One floor L-shaped house
  {typeName = "HOME1_B", description ="1 floor house"}, --One floor house with roof window
  {typeName = "HOME1_C", description ="1 floor house"}, --One floor house with roof window
  {typeName = "HOME2_A", description ="2 floor house (Big)"}, --Two floor big house
  {typeName = "HOME2_B", description ="2 floor house (Big)"}, --Two floor big house
  {typeName = "HOME2_C", description ="2 floor house (Big)"}, --Two floor big house
  {typeName = "HOME3_C", description ="2 floor house (Big)"}, --Two floor big house
  {typeName = "KAM_H", description ="1 floor house / building (Small)"}, --Small one floor building / house
  {typeName = "KLUB_A", description ="1 floor house"}, --Medium one floor house
  {typeName = "KLUB_B", description ="1 floor house"}, --Medium one floor house
  {typeName = "S1_NEW", description ="House (Small)"}, --Small house
  {typeName = "S2_NEW", description ="House (Small)"}, --Small house
  {typeName = "S3_NEW", description ="House"}, --Medium house
  {typeName = "S4_NEW", description ="House (Small)"}, --Small house
}
  

CAUCASUS_HOUSES_BUILDINGS_TYPENAMES = {
  {typeName = "F_HOME3_C", description ="2 floor Building / House (Long)"}, --Long 2 floor building / house
  {typeName = "HOME16A_BASH", description ="6 floor building"}, --6 floor building
  {typeName = "HOME16_BASH", description ="6 floor building"}, --6 floor building
  {typeName = "HOME16_TWIN", description ="16 floor double rectangular building (Big and Tall)"}, --Big tall double rectangular 16 floor building
  {typeName = "HOME1_A_NEW", description ="1 floor House"}, --Small one floor house
  {typeName = "HOME3_A", description ="3 floor building (Big and Long)"}, --Long 3 floor big building
  {typeName = "HOME3_B", description ="3 floor building (Big and Long)"}, --Long 3 floor big building
  {typeName = "HOME3_D", description ="3 floor building (Big and Long)"}, --Long 3 floor big building
  {typeName = "HOME3_E", description ="3 floor building (Big and Long)"}, --Long 3 floor big building
  {typeName = "HOME51_HR", description ="5 floor building (Very Long)"}, --Very long 5 floor building
  {typeName = "HOME51_ST", description ="7 floor building (Big)"}, --Seven floor big building
  {typeName = "HOME52_HR", description ="5 floor building (Very Long)"}, --Very long 5 floor building
  {typeName = "HOME52_ST", description ="5 floor building (Very Long)"}, --Very long 5 floor building
  {typeName = "HOME53_HR", description ="5 floor building (Very Long)"}, --Very long 5 floor building
  {typeName = "HOME53_ST", description ="5 floor building (Very Long)"}, --Very long 5 floor building (4 with windows, 1 with door below)
  {typeName = "HOME5M", description ="5 floor building (Very Long)"}, --Very long 5 floor building
  {typeName = "HOME9A", description ="5 floor building (Very Long)"}, --Very long 9 floor building
}

CAUCASUS_SMALL_CIVILIAN_BUILDINGS_TYPENAMES = {
  {typeName = "BASHNJA-SEA", description ="Coastal tower (Very Small)"}, --Very small coastal tower
  {typeName = "BASHNJA-STENA", description ="2/3 floor Building / Tower (Small)"}, --Small 2/3 floor building / tower
  {typeName = "BASCETBALL", description ="Basketball terrain", validTarget=true}, --Basketball terrain
  {typeName = "BLK_LIGHT_POLE", description ="Light pole"}, --Light pole
  {typeName = "BUFET", description ="1 floor building / cafe with big windows (Small)"}, --Small one floor building with big windows / cafe
  {typeName = "CAFE", description ="1 floor building / cafe with big windows (Small)"}, --Small one floor building with big windows / cafe
  {typeName = "DANSING", description ="Cylindrical open building (Small)"}, --Small one floor cylindrical open building where people can danse
  {typeName = "FOOTBALL", description ="Football terrain (Small)", validTarget=true}, --Small football terrain
  {typeName = "KOMPLEX", description ="Coastal open building", validTarget=true}, --Coastal open building
  {typeName = "KOMPLEX_BIG", description ="Coastal open building (Big)", validTarget=true}, --Big coastal open building
  {typeName = "MAGAZIN_NEW", description ="1 floor house / magasin"}, --Medium one floor house look-alike
  {typeName = "METEOBURO", description ="Building / Tower with radar meteo above (Small)", validTarget=true}, --small building / tower with radar meteo above
  {typeName = "MIG19-MONUMENT", description ="MIG19 MONUMENT", validTarget=true}, --
  {typeName = "MORVOK", description ="3 floor coastal building with big spikes / tower", validTarget=true}, --3 floor coastal building with big spikes / tower
  {typeName = "OBSERV", description ="Astronomy observatory", validTarget=true}, --Astronomy observatory
  {typeName = "PAVILYON", description ="Closed cylindrical one floor building with windows (Small)"}, --closed small cylindrical one floor building with windows
  {typeName = "PAVILYON1_NEW", description ="1 floor house (Small)"}, --Small one floor house
  {typeName = "PEREHOD", description ="Coastal wall", validTarget=true}, --coastal wall
  {typeName = "PRICHAL", description ="Coastal platform / pier part", validTarget=true}, --coastal platform / pier part
  {typeName = "ROKITUNNELENTRANCE01", description ="Tunnel entrance", validTarget=true}, --Tunnel entrance
  {typeName = "SECTION_MAIN", description ="Coastal open building (Small)"}, --Small coastal open building
  {typeName = "STADION_SMALL", description ="Athletic / Football Stadium", validTarget=true}, --Athletic / football stadium
  {typeName = "STANCIJA3", description ="2 floor building with windows"}, --Two floor building with windows
  {typeName = "TENNIS", description ="Tennis court", validTarget=true}, --Tennis court
  {typeName = "TR_BUDKA_NEW", description ="1 floor stand / storage facility (Small)"}, --Small one floor stand/storage facility/building with flat roof
  {typeName = "TUNNEL_ENTRANCE_CAUC_01", description ="Tunnel entrance", validTarget=true}, --Tunnel entrance
  {typeName = "VOLNOREZ", description ="Coastal Dyke / Sea wall", validTarget=true}, --coastal dyke /sea wall
  {typeName = "WC_NEW", description ="Small WC building"}, --Small WC building
}
  

CAUCASUS_BIG_BUILDINGS_TYPENAMES = {
  {typeName = "CINEMA_A", description ="Cinema complex with wide windows (Big)"}, --Big multifloor building with windows only on one side and flat roof / cinema
  {typeName = "CINEMA_B", description ="Cinema complex with wide windows (Big and long)"}, --Big and long one floor building / warehouse with a lot of windows
  {typeName = "D_SAD_A", description ="3 floor double H shaped building (Big)"}, --Double H two floor and a half big building
  {typeName = "KORPUS", description ="3/4 floor Building (Big)"}, --big 3/4 floor building
  {typeName = "KORPUS_A", description ="3/4 floor Building (Big)"}, --big 3/4 floor building
  {typeName = "KORPUS_A1", description ="5 floor Building (Big)"}, --big 5 floor building
  {typeName = "KORPUS_B", description ="4 floor Building (Big)"}, --big 4 floor building
  {typeName = "KORPUS_B1", description ="3 floor Building (Big)"}, --big 3 floor building
  {typeName = "KORPUS_C", description ="5 floor Building (Big)"}, --Big 5 floor building
  {typeName = "KORPUS_D", description ="6/8 floor Building (Big)"}, --Big six floor building linked to an eight floor building
  {typeName = "RESTORAN1_NEW", description ="2 floor Restaurant / Mansion"}, --Medium 2 floor building used for restaurant or governor mansion
  {typeName = "SCHOOL_A", description ="3 floor H-shaped Building / School (Big)"}, --H shaped big three floor building
  {typeName = "UNIWERSAM_A_NEW", description ="2 floor Building (Big)"}, --Two floors building with a small protusion
}

CAUCASUS_HOSPITALS_TYPENAMES = {
  {typeName = "POLYKLINIKA_A", description ="4 floor Building / Clinic (Big)", validTarget=true}, --Big 4 floor building with flat roof / clinic / nursing home
}

CAUCASUS_HOTELS_TYPENAMES = {
  {typeName = "HOTEL_A", description ="9 floor Building / Hotel (Very Long)", validTarget=true}, --Very long 9 floor building / hotel
  {typeName = "HOTEL_B", description ="7/9 floor Hotel (Very Long)", validTarget=true}, --Very long 7/9 floor building / hotel with hotel written on top
  {typeName = "HOTEL_C", description ="9 floor Building / Hotel (Very Long)", validTarget=true}, --Very long 9 floor building / hotel
}

CAUCASUS_OLD_BUILDINGS_RUINS_TYPENAMES = {
}

CAUCASUS_RELIGIOUS_TYPENAMES = {
  {typeName = "MECHET", description ="Round top mosque", validTarget=true}, --Mosque with a round top
  {typeName = "MECHET_HIGHT", description ="Mosque tower", validTarget=true}, --high mosque tower
}

CAUCASUS_SMALL_INDUSTRIAL_TARGETS_TYPENAMES = {
  {typeName = "KOTELNAYA_A_NEW", description ="Factory with a chimney (Small)", validTarget=true}, --Small warehouse with chimney - Boiler room A ?
  {typeName = "KOTELNAYA_B", description ="Factory L-shaped with a chimney (Small)", validTarget=true}, --L shaped warehouse with chimney - BOILER ROOM B ?
  {typeName = "NASOS", description ="Derrick nodding-donkey pump (Small)", validTarget=true}, --Small Derrik nodding-donkey pump
}
  
CAUCASUS_INDUSTRIAL_TARGETS_TYPENAMES = {
  {typeName = "GRADIR", description ="Cooling tower (Big and tall)", validTarget=true}, --Big nuclear-like cooling tower / chimney
  {typeName = "KORPUS_ATOM", description ="Factory / Power plant with 2 chimney (Big and tall)", validTarget=true}, --multi floor factory with two chimney -  power plant
  {typeName = "LAP-HOUSE", description ="2/4 floor building linked to electricity network (Big)", validTarget=true}, --Big two floor building with four floor building attached and linked to the electricity network
  {typeName = "STOP_LIGHT_RED", description ="Derrick tower (Tall)", validTarget=true}, --Derrik big tower with flame above
  {typeName = "TEC_A_NEW", description ="Factory with 4 chimney (Big)", validTarget=true}, --Big factory with 4 chimney and citerns around
  {typeName = "TELE_BASH_M_NEW", description ="Radio / TV antenna tower (Tall)", validTarget=true}, --Huge TV antenna tower
  {typeName = "TELE_BASH_NEW", description ="Radio / TV antenna tower (Tall)", validTarget=true}, --Huge TV antenna tower
  {typeName = "TUAPSE_BUILDING2", description ="2 floor building", validTarget=true}, --Two floor building with roof access via stairs
  {typeName = "TUAPSE_DEOILER", description ="5 floor building deoiler with a chimney and 2 tanks", validTarget=true}, --5 floors building deoiler with a chimney and two tanks
  {typeName = "TUAPSE_TOWERA", description ="Oil refinery tower (Big)", validTarget=true}, --Big oil refinery tower
  {typeName = "TUAPSE_TOWERB", description ="Oil refinery tower (Big)", validTarget=true}, --Big oil refinery tower
  {typeName = "TUAPSE_TOWERC", description ="Oil refinery tower (Big)", validTarget=true}, --Big oil refinery tower
}

CAUCASUS_WATER_TOWER_TYPENAMES = {
  {typeName = "WODOKACHKA_A_NEW", description ="Water tower", validTarget=true}, --Three floor Water tower
  {typeName = "WODOKACHKA_B", description ="Water tower", validTarget=true}, --Three floor Water tower
  {typeName = "WODOKACHKA_C", description ="Water tower", validTarget=true}, --Three floor Water tower
}

CAUCASUS_MILITARY_TARGETS_TYPENAMES = {
  {typeName = "ATZ-60", description ="ATZ-60 / Very long fuel truck", validTarget=true}, --Very long fuel truck
  {typeName = "BTR-80", description ="BTR-80", validTarget=true}, --
  {typeName = "KAMAZ-FIRE", description ="Kamaz fire truck", validTarget=true}, --Fire truck
  {typeName = "KAMAZ-TENT", description ="Kamaz truck with tent above its load", validTarget=true}, --Truck with tent above its load
  {typeName = "KAZARMA1_NEW", description ="1 floor Caserne (Big)"}, --Big one floor Caserne --Looks to much as a house / building to be used
  {typeName = "KAZARMA2_NEW", description ="1 floor Caserne (Long)"}, --Long one floor Caserne --Looks to much as a house / building to be used
  {typeName = "URAL-APA", description ="Ural truck with 3 boxes behind", validTarget=true}, --Truck with 3 boxes behind
  {typeName = "URAL_4320-31", description ="Camo Ural truck with tent above its load", validTarget=true}, --Camo truck with tent above its load
  {typeName = "URAL_4320_B", description ="Ural Truck with ammo", validTarget=true}, --Truck with ammo 
  {typeName = "URAL_4320_K", description ="Command post Ural truck", validTarget=true}, --Command post Ural truck
  {typeName = "URAL_4320_T", description ="Truck with tent above its load", validTarget=true}, --Truck with tent above its load
  {typeName = "URAL_ATMZ-5", description ="Truck fuel citern", validTarget=true}, --Small Truck fuel citern
  {typeName = "URAL_ATZ-10", description ="Truck fuel citern", validTarget=true}, --Small Truck fuel citern
  {typeName = "GAZ-66", description ="Truck", validTarget=true}, --
}

CAUCASUS_LIGHTHOUSE_TYPENAMES = {
  {typeName = "MAJAK", description ="Lighthouse", validTarget=true}, --Lighthouse
  {typeName = "MAJAK-1", description ="Lighthouse", validTarget=true}, --Lighthouse
}



--Small objects and all not really specific buildings
SYRIA_AIRPORT_SMALL_OBJECTS_TYPENAMES = {
  {typeName = "A4SKYHAWK", description ="Static A4 aircraft monument"}, --Indestructible Unique
  {typeName = "AIRBASE_ANTENNA_01", description ="Red and white 3 floor tall antenna"}, --
  {typeName = "AKROTIRI_ENTRANCE", description ="Airfield entrance panel"}, --Indestructible Unique
  {typeName = "AIRFIELDS_BUILDING_1", description ="2 floor building"}, --
  {typeName = "AIRFIELDS_BUILDING_13", description ="1 floor building"}, --
  {typeName = "AIRFIELDS_BUILDING_14", description ="2 floor building (Long)", validTarget=true}, --
  {typeName = "AIRFIELDS_BUILDING_19_2", description ="2 floor building"}, --
  {typeName = "AIRFIELDS_BUILDING_2", description ="2 floor building with a dish on top", validTarget=true}, --
  {typeName = "AIRFIELDS_BUILDING_20", description ="2/3 floor building", validTarget=true}, --
  {typeName = "AIRFIELDS_BUILDING_21", description ="2/3 floor building", validTarget=true}, --
  {typeName = "AIRFIELDS_BUILDING_24", description ="Big shades open"}, --
  {typeName = "AIRFIELDS_BUILDING_25", description ="2 floor building"}, --
  {typeName = "AIRFIELDS_BUILDING_27", description ="1/2 floor L shaped building"}, --
  {typeName = "AIRFIELDS_BUILDING_5", description ="2 floor airfield building"}, --
  {typeName = "AIRFIELDS_BUILDING_6", description ="2 floor airfield building partly open"}, --
  {typeName = "AIRFIELDS_BUILDING_7", description ="2 floor airfield building (Small)"}, --
  {typeName = "AIRFIELDS_BUILDING_8_1", description ="1 floor building"}, --
  {typeName = "BAK12", description ="Small BAK12 Red and grey casemate (Small)"}, --
  {typeName = "CONCRETECOVER", description ="Concrete cover"}, --
  {typeName = "F-4E", description ="Static F-4E aircraft monument"}, --Indestructible Unique
  {typeName = "FIRETRAINING", description ="Fire training aircraft replica"}, --Indestructible
  {typeName = "INCIRLIK_RADAR_ANTENNA", description ="Portative radar antenna"}, --Indestructible Unique
  {typeName = "MD500", description ="Static MD500 helicopter"}, --Indestructible
  {typeName = "METEOR", description ="Meteor aircraft monument"}, --Indestructible Unique
  {typeName = "MYSTEREIV", description ="Mystere IV aircraft monument", validTarget=true}, --
  {typeName = "RSBN_GENER", description ="RSBN Generator"}, --Indestructible Target not visible?
  {typeName = "RSP_ESD-20", description ="RSP Generator"}, --Small generator on wheels in airports --Indestructible
  {typeName = "SOCK", description ="Wind sock"}, --
  {typeName = "SOCK_MILITARY", description ="Wind sock"}, --
  {typeName = "TAXI_OMNI_BLUE", description ="Blue taxi light"}, --
  {typeName = "VAUTOUR", description ="Static Vautour Aircraft monument"}, --Indestructible Unique
  {typeName = "VOR_DME", description ="VOR DME Antenna"}, --
}

SYRIA_AIRPORT_STRATEGIC_TARGETS_TYPENAMES = {
  {typeName = "AIRBUS_A300", description ="Static white A300 airliner", validTarget=true},
  {typeName = "AIRFIELDS_BUILDING_19", description ="5 linked aircraft hangar", validTarget=true}, --
  {typeName = "AIRFIELDS_BUILDING_23", description ="Two linked rectangular aircraft hangar (Tall)", validTarget=true}, --
  {typeName = "AIRFIELDS_BUILDING_33", description ="Two floor warehouse (Long and large)", validTarget=true}, --
  {typeName = "AIRFIELDS_HANGAR_01", description ="Airfield hangar (Large)", validTarget=true}, --
  {typeName = "AIRFIELDS_HANGAR_01_GB", description ="Airfield hangar with a british flag inside", validTarget=true}, --
  {typeName = "AIRFIELDS_HANGAR_01_SIGN", description ="Airfield hangar with a sign", validTarget=true}, --
  {typeName = "AIRPORT_BUILDING1", description ="Airport terminal"}, --Indestructible - Bassel El Assad only
  {typeName = "AIRFIELDS_BUILDING_43", description ="5 floor building", validTarget=true}, --
  {typeName = "AIRPORT_BUILDING1_TOWER", description ="Port / Airport ATC Control tower"}, --Indestructible
  {typeName = "ALEPPO_TERMINAL", description ="Multifloor airport terminal with tower on top"}, --Indestructible- Unique
  {typeName = "ATC_CONTROL_TOWER", description ="ATC Control tower", validTarget=true}, --
  {typeName = "AN_26_CIVIL", description ="AN-26 civil aircraft", validTarget=true}, --
  {typeName = "BEIRUT_TERMINAL_1", description ="Airport terminal"}, -- Beirut airport terminal above the V runway crosspath -Indestructible
  {typeName = "BEIRUT_TERMINAL_2", description ="Airport terminal"}, -- Beirut airport terminal above the V runway crosspath -Indestructible
  {typeName = "BEIRUT_TERMINAL_3", description ="Airport terminal"}, -- Beirut airport terminal above the V runway crosspath -Indestructible
  {typeName = "BEIRUT_TERMINAL_4", description ="Airport terminal"}, -- Beirut airport terminal above the V runway crosspath -Indestructible
  {typeName = "BEIRUT_TERMINAL_5", description ="Airport terminal"}, -- Beirut airport terminal above the V runway crosspath -Indestructible
  {typeName = "DAMASCUS_TERMINAL", description ="Airport terminal"}, --Indestructible Unique
  {typeName = "DAMASCUS_TERMINAL_TOWER", description ="Airport tower (Tall)"}, --Indestructible Unique
  {typeName = "GAZIANTEP_TERMINAL", description ="Airport terminal"}, --Indestructible Unique
  {typeName = "HANGAR_02", description ="Aircraft hangar (Big and tall)"}, --Indestructible - Two on Incirlik
  {typeName = "HANGAR_03", description ="Aircraft hangar (Big)"}, --Indestructible Unique on Incirlik
  {typeName = "HANGAR_AKROTIRI", description ="Green shell shaped cylindrical aircraft hangar", validTarget=true},
  {typeName = "HANGAR_COVER", description ="Hangar", validTarget=true}, --  
  {typeName = "HANGARCOVERED", description ="Twin ground covered cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGARCOVERED2", description ="Ground covered cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGARCOVERED2_GREEN", description ="Green ground covered cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGARCOVERED3", description ="Ground covered cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGARCOVERED3_GREEN", description ="Green ground covered cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGARCOVERED_GATES", description ="Green ground covered cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGARCOVERED_GREEN", description ="Twin green ground covered cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGAR_DOUBLE", description ="Double spherical hangar", validTarget=true}, --
  {typeName = "HANGARLONG1", description ="9 Link green ground covered cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGARLONG_GROUND", description ="Very Long wall behind cylindrical aircraft hanger with green ground on one side", validTarget=true}, --
  {typeName = "HANGAR_MILLITARY1", description ="Cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGAR_MILLITARY2", description ="Cylindrical aircraft hangar", validTarget=true}, --
  {typeName = "HANGAR_MILLITARY2_CLOSE", description ="Cylindrical aircraft hangar with flag on entrance", validTarget=true}, --
  {typeName = "HELIPORT", description ="Heliport", validTarget=true}, --
  {typeName = "HELIPORT_MED", description ="Medical helipad", validTarget=true},
  {typeName = "HELIPORT_UN", description ="UN Heliport", validTarget=true},
  {typeName = "HUNGAR_016", description ="Aircraft hangar", validTarget=true}, --
  {typeName = "HUNGAR_031", description ="Aircraft hangar with reactor pipe exhaust for test", validTarget=true}, --
  {typeName = "IL76_SILKWAY", description ="Static IL-76 civil aircraft", validTarget=true},
  {typeName = "KDP", description ="Airport control tower", validTarget=true}, --
  {typeName = "LATAKIA_HANGAR_03", description ="Triple rectangular aircraft hangar with jet blast deflectors"}, --Indestructible
  {typeName = "LARNACA_TERMINAL", description ="Civil aircraft terminal (Big)"}, --Indestructible Unique
  {typeName = "LEARJET_85", description ="Static Learjet 85 aircraft", validTarget=true},
  {typeName = "NICOSIA_TERMINAL", description ="Civil aircraft terminal"}, --Indestructible Unique
  {typeName = "PAPHOS_TERMINAL", description ="Civil aircraft terminal (Big)"}, --Indestructible Unique
  {typeName = "OPEN_HANGAR_BIG", description ="Aircraft hanger (Big and tall)", validTarget=true}, --
  {typeName = "OPEN_HANGAR_SMALL", description ="Aircraft hanger", validTarget=true}, --
  {typeName = "TURKEY_TRIANGLE_FLAG", description ="Aircraft hangar with turkish flag at the entry"}, --Just the flag or the full hangar? Indestructible
}

SYRIA_PORT_STRATEGIC_TARGETS_TYPENAMES = {
  {typeName = "LIMASOL_NEW_PORT_TERMINAL", description ="Long multifloor port terminal"}, --Indestructible -Unique
}

SYRIA_OFFSHORE_OIL_RIG_TYPENAMES = {
}

SYRIA_RAILWAY_STRATEGIC_TARGETS_TYPENAMES = {
  {typeName = "RAILSTATION", description ="2 floor rail station (big)"}, --Indestructible
}

SYRIA_RAILWAY_BRIDGES_TYPENAMES = {
  {typeName = "RW_BRIDGE_1LINE", description ="Railway bridge (1 way)", validTarget=true}, --
  {typeName = "RW_BRIDGE_2LINE", description ="Railway bridge (2 way)", validTarget=true}, --
}

SYRIA_ROAD_BRIDGES_TYPENAMES = {
  {typeName = "ADANA_BRIDGE", description ="Road bridge (Long)"}, --Indestructible
  {typeName = "CAR_BRIDGE_2LINE", description ="Road bridge section (Small)", validTarget=true}, --
  {typeName = "CAR_BRIDGE_2LINE_TOWN", description ="Road bridge section (Small)", validTarget=true}, --
  {typeName = "CAR_BRIDGE_4LINE", description ="Road bridge section (Small)", validTarget=true}, --
  {typeName = "CAR_BRIDGE_4LINE_TOWN", description ="Road bridge section (Small)", validTarget=true}, --
  {typeName = "WOODEN_BRIDGE_2LINE", description ="Wooden road bridge 2 way section (Small)", validTarget=true}, --
  {typeName = "WOODEN_SUPPORT", description ="Wooden road bridge (Small)"}, --Indestructible
}

SYRIA_TANKS_TYPENAMES = {
  {typeName = "AIRBASE_TBILISI_TANK_01", description ="Cylindrical liquid tank (Tall)", validTarget=true}, --
  {typeName = "AIRBASE_TBILISI_TANK_02", description ="Cylindrical liquid tank (Tall)", validTarget=true}, --
  {typeName = "CONCREET_CAN", description ="Two floor tall cylindrical tank on feet", validTarget=true}, --
  {typeName = "FUEL_STORAGE_TANKS", description ="Two cylindrical liquid tank (Big and tall)", validTarget=true}, --
  {typeName = "LIQ_TANK", description ="Cylindrical liquid tank ", validTarget=true}, --
  {typeName = "LIQ_TANK_BIG", description ="Cylindrical liquid tank (Big)", validTarget=true}, --
  {typeName = "US_AFB_LIQ_TANK_02", description ="Cylindrical liquid tank (Tall)", validTarget=true}, --
}


SYRIA_VERY_SMALL_WAREHOUSES_TYPENAMES = {
  {typeName = "BENGAL_COMERCIAL_BUILDING_03", description ="Warehouse (Small)"}, --
  {typeName = "WAREHOUSE", description ="Cylindrical warehouse (Small)"}, --
}


SYRIA_SMALL_WAREHOUSES_TYPENAMES = {
  {typeName = "AIRBASE_WAREHOUSE_01", description ="Warehouse (Very very small)"},
  {typeName = "BENGAL_INDUSTRIAL_OBJECT_04", description ="1 floor warehouse (Small)"}, --
  {typeName = "BENGAL_INDUSTRIAL_OBJECT_08", description ="Two floor warehouse (Small)"}, --
  {typeName = "GREENHOUSE1", description ="Greenhouse (Long and small)"}, --Small and long one floor greenhouse
  {typeName = "GREENHOUSE2", description ="Greenhouse (Long and small)"}, --Small and long one floor greenhouse
  {typeName = "INDUSTRIAL_HANGAR_02", description ="Cylindrical hanger (Long and small)"}, --
  {typeName = "INDUSTRIAL_UN", description ="1.5 floor warehouse with slope top"}, --
}

SYRIA_MEDIUM_WAREHOUSES_TYPENAMES = {
  {typeName = "AIRBASE_AIRPORT_TBILISI_HANGAR_01", description ="Hangar (Long)", validTarget=true}, --Long hangar - Move to medium
  {typeName = "AIRFIELDS_HANGAR_03", description ="Hangar / warehouse ", validTarget=true}, --
  {typeName = "BAGRAM_INDUSTRIAL_01", description ="1 floor warehouse", validTarget=true}, --
  {typeName = "BENGAL_INDUSTRIAL_OBJECT_05", description ="Two floor grey warehouse with windows on the side", validTarget=true}, --
  {typeName = "BENGAL_INDUSTRIAL_OBJECT_06", description ="Two floor grey warehouse (Long)", validTarget=true}, --
  {typeName = "BENGAL_INDUSTRIAL_OBJECT_07", description ="One floor brick warehouse (Long)", validTarget=true}, --
  {typeName = "BENGAL_INDUSTRIAL_OBJECT_09", description ="One floor brick warehouse (Long)", validTarget=true}, --
  {typeName = "CONCORD_FACIL_02", description ="1 floor warehouse", validTarget=true}, --
  {typeName = "CG_BUILDING07", description ="1/2 floor multiple warehouse", validTarget=true}, --
  {typeName = "HUNGAR_032", description ="2/4 floor warehouse (Long)", validTarget=true}, --
  {typeName = "HUNGAR_036", description ="2 floor warehouse (Long)", validTarget=true}, --
  {typeName = "HUNGAR_041", description ="2 floor warehouse (Long)", validTarget=true}, --
  {typeName = "HUNGAR_042", description ="1 floor warehouse", validTarget=true}, --
  {typeName = "NEVAD_VEGAS_INDUSTRIAL_03", description ="One floor warehouse (Long)", validTarget=true}, --
  {typeName = "NEVAD_VEGAS_INDUSTRIAL_04", description ="One floor brick warehouse (Long)", validTarget=true}, --
  {typeName = "WAREHOUSE_BLOCK", description ="Small 8 warehouses block"}, --Invalid because destroyable but no visual difference
}

SYRIA_BIG_WAREHOUSES_TYPENAMES = {
  {typeName = "HUNGAR_023", description ="Two floor brick warehouse (Long)", validTarget=true}, --
}

SYRIA_HOUSES_TYPENAMES = {
  {typeName = "HOUSE_VILLAGE_11", description ="2 floor house"}, --
  {typeName = "ISRAEL_BLOCK_BUILDING_03", description ="2 floor house with red top"}, --
  {typeName = "ISRAEL_BLOCK_BUILDING_05", description ="2 floor house"}, --
  {typeName = "ISRAEL_HOUSE_02", description ="2 floor house"}, --
  {typeName = "ISRAEL_HOUSE_03", description ="2 floor house"}, --
  {typeName = "ISRAEL_HOUSE_10", description ="2 floor house with solar panels"}, --
  {typeName = "ISRAEL_HOUSE_12", description ="2 floor house with solar panels"}, --
  {typeName = "ISRAEL_TOWN_HOUSE_01", description ="2 floor house with solar panels"}, --
  {typeName = "NEVADA_VEGAS_HOUSE_11", description ="2 floor house with solar panels (Big)"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_04", description ="2 floor residential building"}, --Two floor residential building
  {typeName = "SYRIA_BLOCK_BUILDING_06", description ="1 floor residential building (Small)"}, --One floor small residential building
  {typeName = "SYRIA_CITY_HOUSE_05", description ="2 floor House"}, --
  {typeName = "SYRIA_HOUSE_01", description ="2 floor L-shaped house"}, --
  {typeName = "SYRIA_HOUSE_02", description ="2 floor house (Small)"}, --Small two floor house
  {typeName = "SYRIA_HOUSE_03", description ="2 floor house (Small)"}, --Small two floor house
  {typeName = "SYRIA_HOUSE_04", description ="2 floor house (Small)"}, --
  {typeName = "SYRIA_HOUSE_06", description ="1 floor house (Very very small)"}, --
  {typeName = "SYRIA_HOUSE_08", description ="1 floor house (Small)"}, --Small one floor house
  {typeName = "SYRIA_HOUSE_09", description ="1 floor house with half-sphere on top"}, --
  {typeName = "VILLAGE_HOUSE_02", description ="2 floor house"}, --
}

SYRIA_HOUSES_BUILDINGS_TYPENAMES = {
  {typeName = "BEIRUT_BUILDING", description ="4 floor residential building"}, --
  {typeName = "BENGAL_CITY_HOUSE_07", description ="6 floor residential building"}, --
  {typeName = "BENGAL_COMERCIAL_BUILDING_01", description ="2 floor residential building (Very small)"}, --
  {typeName = "BENGAL_COMERCIAL_BUILDING_02", description ="2 floor residential building"}, --
  {typeName = "CONSTRUCTION", description ="3 floor residential building early construction"}, --
  {typeName = "ISRAEL_BLOCK_BUILDING_09", description ="4 floor residential building with a red roof"}, --
  {typeName = "ISRAEL_CITY_HOUSE_03", description ="4 floor residential building"}, --
  {typeName = "ISRAEL_CITY_HOUSE_05", description ="5 floor residential building with a red roof"}, --
  {typeName = "RED_ROOF_HOUSE1B", description ="6 floor residential building with a red roof"}, --
  {typeName = "RED_ROOF_HOUSE2C", description ="2 floor residential building with a red roof"}, --
  {typeName = "RED_ROOF_HOUSE3", description =""}, --
  {typeName = "RED_ROOF_HOUSE3C", description ="3 floor residential building with a red roof"}, --
  {typeName = "RED_ROOF_HOUSE4", description ="7 floor residential building with a red roof"}, --
  {typeName = "RED_ROOF_HOUSE4C", description ="2/3 floor residential building with a red roof"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_01", description ="2 floor residential building (Small)"}, --Small 2 floor residential building
  {typeName = "SYRIA_BLOCK_BUILDING_02", description ="8 floor residential building"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_03", description ="2 floor building"}, --2 floor building --In list but not found on map
  {typeName = "SYRIA_BLOCK_BUILDING_05", description ="2 floor building"}, --2 floor building
  {typeName = "SYRIA_BLOCK_BUILDING_09", description ="4 floor residential building (Small)"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_10", description ="3 floor residential building"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_11", description ="5 floor residential building (Small)"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_12", description ="6 floor residential building"}, --6 floor residential building
  {typeName = "SYRIA_BLOCK_BUILDING_13", description ="5 floor residential building"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_14", description ="8 floor residential building"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_15", description ="7 floor residential building"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_16", description ="4 floor residential building with solar panel on top"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_17", description ="4 floor residential building"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_18", description ="6 floor residential building"}, --
  {typeName = "SYRIA_BLOCK_BUILDING_19", description ="4 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_02", description ="2 floor house (Big)"}, --Big 2 floor house with inside "garden" and house around
  {typeName = "SYRIA_CITY_HOUSE_031", description ="4 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_041", description ="4/5 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_051", description ="5 floor Building"}, --5 floor building
  {typeName = "SYRIA_CITY_HOUSE_061", description ="5/6 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_071", description ="6/7 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_081", description ="6 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_091", description ="7 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_10", description ="6/7 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_11", description ="7 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_12", description ="8 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_13", description ="8 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_14", description ="9 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_15", description ="10 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_16L", description ="16 floor residential building"}, --
  {typeName = "SYRIA_CITY_HOUSE_20L", description ="20 floor residential building"}, --
  {typeName = "SYRIA_HOUSE01_BUILDING", description ="6 floor residential building"}, --
  {typeName = "SYRIA_HOUSE_011", description ="15+ floor residential building"}, --
  {typeName = "SYRIA_HOUSE_041", description ="11 floor residential building"}, --
  {typeName = "SYRIA_TOWER", description ="9 floor residential building"}, --
  {typeName = "TRIANGLE", description ="2/4 floor triangle residential building"}, --Indestructible - Unique
  {typeName = "TRIANGLE1", description ="4 floor triangle residential building"}, --Indestructible
  {typeName = "TURKEY_BLOCK_BUILDING_09", description ="4 floor residential building"}, --
  {typeName = "TURKEY_BLOCK_BUILDING_10", description ="3 floor residential building (Small)"}, --
  {typeName = "TURKEY_BLOCK_BUILDING_11", description ="5 floor residential building"}, --
  {typeName = "TURKEY_BLOCK_BUILDING_18", description ="6 floor residential building"}, --
  {typeName = "TURKEY_CITY_HOUSE_02", description ="3 floor residential building"}, --
  {typeName = "TURKEY_CITY_HOUSE_04", description ="4 floor residential building"}, --
  {typeName = "TURKEY_CITY_HOUSE_09", description ="6 floor residential building"}, --
  {typeName = "TURKEY_CITY_HOUSE_10", description ="7 floor residential building"}, --
  {typeName = "UNIVERSITYHOUSE", description ="2 floor residential buildings group with solar panel on top"}, --Indestructible
}

SYRIA_HOSPITALS_TYPENAMES = {
  {typeName = "ADANA_CITYEDUCATION_AND_RESEARCHHOSPITAL_1", description ="Hospital (Very big)"}, --Indestructible Unique
  {typeName = "ADANA_CITYEDUCATION_AND_RESEARCHHOSPITAL_2", description ="Hospital (Very big)"}, --Indestructible Unique
  {typeName = "ADANA_CITYEDUCATION_AND_RESEARCHHOSPITAL_3", description ="Hospital (Very big)"}, --Indestructible Unique
  {typeName = "ADANA_CITYEDUCATION_AND_RESEARCHHOSPITAL_4", description ="Hospital (Very big)"}, --Indestructible Unique
  {typeName = "ADANA_YUREGIR_HOSPITAL", description ="Hospital (Big)"}, --Indestructible Unique
  {typeName = "HAIFA_CARMEL_MEDICAL_CENTER", description ="Multifloor medical center (Big and tall)"}, --Indestructible Unique
  {typeName = "LARNACA_GENERAL_HOSPITAL", description ="8 floor hospital"}, --Indestructible Unique
  {typeName = "LIMASSOL_GENERAL_HOSPITAL", description ="Multifloor hospital"}, --Indestructible Unique
  {typeName = "NICOSIA_GENERAL_HOSPITAL", description ="Hospital (Big)"}, --Indestructible Unique
  {typeName = "PAPHOS_GENERAL_HOSPITAL", description ="Hospital (Big)"}, --Indestructible
  {typeName = "RAMBAM_HEALTH_CARE", description ="Hospital / healt car campus (Tall)"}, --Indestructible Unique
  {typeName = "SAINT_VIC_HOSPITAL_UNIVERSITY_MEDICAL_CENTER", description ="10+ floor T-shape hospital"}, --Indestructible Unique
}

SYRIA_HOTELS_TYPENAMES = {
  {typeName = "ADANA_HILTON_SA", description ="Multifloor hotel with two towers"}, --Indestructible Unique
  {typeName = "DAMASCUS_FUTURE_HOTEL", description ="Work in progress multifloor hotel"}, --Indestructible Unique
  {typeName = "DAMASCUS_SHERATON_HOTEL", description ="7 floor Luxe Hotel"}, --Indestructible Unique
  {typeName = "HOTEL_01", description ="5 floor hotel (Long)"}, --Indestructible Unique
  {typeName = "HOTEL_02", description ="7 floor hotel with solar panels on top"}, --Indestructible Unique
  {typeName = "HOTEL_03", description ="8 floor Queens hotel (Small)"}, --Indestructible Unique
  {typeName = "HOTEL_04", description ="4 floor U-shaped hotel with solar panels on top"}, --Indestructible Unique
  {typeName = "HOTEL_05", description ="8 floor hotel with solar panels on top"}, --Indestructible Unique
  {typeName = "HOTEL_06", description ="5 floor triangle shaped hotel with solar panels on top"}, --Indestructible Unique
  {typeName = "HOTEL_FOURSEASONS", description ="20+ floor hotel"}, --Indestructible Unique
  {typeName = "KYRENIAS_SAINT_HILARION_CASTLE", description ="Old castle"}, --Indestructible Unique
  {typeName = "LARNACA_RADISSON_BLU_HOTEL", description ="Multifloor multi buildings hotel with pool on one top"}, --Indestructible Unique
  {typeName = "KYRENIA_MERCURE_HOTEL_CASINO", description ="8 shaped Mars Hotel"}, ----Indestructible Unique
  {typeName = "LIMASSOL_OLYMPIC_RESIDENCE", description ="Twin multifloor building hotel"}, --Indestructible Unique
  {typeName = "PAPHOS_AMATHUS_BEACH_HOTEL", description ="4/5 floor double U shape hotel with red roof top (Big and large)"}, --Indestructible Unique
  {typeName = "SHERATON_ADANA_HOTEL", description ="Seraton hotel (Big)"}, --Indestructible Unique
}

SYRIA_OLD_BUILDINGS_RUINS_TYPENAMES = {
  {typeName = "ACRE_OLD_TOWN", description ="Old castle"}, --Indestructible -Unique
  {typeName = "ACRE_OLD_TOWN_WALL1", description ="Old wall / monument (Long)"}, --Indestructible -Unique
  {typeName = "ACRE_OLD_TOWN_WALL2", description ="Old wall / monument (Long)"}, --Indestructible -Unique
  {typeName = "ALEPPO_CITADEL_BUILDING", description ="Citadel (Big)"}, --Indestructible -Unique
  {typeName = "ALEPPO_TOWER_BUILDING", description ="Old tower monument"}, --Indestructible -Unique
  {typeName = "AMPHITHEATRE", description ="Old amphitheatre monument"}, --Indestructible -Unique
  {typeName = "ARC1", description ="Old arch"}, --Indestructible
  {typeName = "BAALSHAMIN_TEMPLE", description ="Old temple / monument"}, --Indestructible -Unique
  {typeName = "FAMAGUSTA_CASTLE", description ="Old city castle and walls (Very big)"}, --Indestructible -Unique
  {typeName = "FUNERARY_TEMPLE", description ="Old Funerary temple"}, --Indestructible
  {typeName = "GAZIANTEP_CASTLE", description ="Castle"}, --Indestructible -Unique
  {typeName = "HAIFA_BAHAI_ARCHIVE", description ="Old temple with columns"}, --Indestructible -Unique
  {typeName = "KRAK_DE_CHEVALIERS", description ="Castle (Big and tall)"}, --Indestructible -Unique
  {typeName = "KYRENIAS_CYRENE_CASTLE", description ="Castle"}, --Indestructible -Unique
  {typeName = "NORIA1", description ="River water wheel"}, --Indestructible -Unique
  {typeName = "NORIA2", description ="Old rover water monument"}, --Indestructible -Unique
  {typeName = "PALMYRA_AMPHITHEATRE_BUILDING", description ="Old amphitheatre"}, --Indestructible -Unique
  {typeName = "PALMYRA_CASTLE_BUILDING", description ="Castle (Big)"}, --Indestructible -Unique
  {typeName = "PALMIRA_TETRAPYLON", description ="Old pylons monument"}, --Indestructible -Unique
  {typeName = "RUINED_COLUMN_TEMPLE", description ="Old monument columns (Tall)"}, --Indestructible
  {typeName = "RUINES1", description ="Old monument columns (Tall)"}, --Indestructible
  {typeName = "RUINES2", description ="Old monument columns (Tall)"}, --Indestructible
  {typeName = "RUINES3", description ="Old monument columns (Tall)"}, --Indestructible
  {typeName = "RUINES4", description ="Old monument columns (Tall)"}, --Indestructible
  {typeName = "TEMPLEOFBACCHUS", description ="Old temple"}, --Indestructible -Unique
  {typeName = "TRIPOLY_CITADEL_1", description ="Old citadel / monument (Big)"}, --Indestructible -Unique
  {typeName = "TRIPOLY_CITADEL_2", description ="Old citadel / monument (Big)"}, --Indestructible -Unique
  {typeName = "TRIPOLY_CITADEL_3", description ="Old citadel / monument (Big)"}, --Indestructible -Unique
}

SYRIA_RELIGIOUS_TYPENAMES = {
  {typeName = "ARABIAN_BLOCK_BUILDING_20", description ="Mosque with two towers and one dome", validTarget=true}, --
  {typeName = "ARABIAN_BLOCK_BUILDING_21", description ="3 floors Mosque with dome", validTarget=true}, --
  {typeName = "ARMENIAN", description ="Church (Big and tall)", validTarget=true}, --
  {typeName = "BEIRUT_DEIR_EL_SALIB", description ="Church / Monastery (Big)"}, --Indestructible -Unique
  {typeName = "CYPRUS_KARAOGLANOGLU_CEMETRY", description ="Graveyard"}, --Indestructible -Unique
  {typeName = "HAIFA_BAHAI_MAUSOLEUM", description ="Mausoleum"}, --Indestructible -Unique
  {typeName = "LATAKIA_AIRFIELD_MOSQUE", description ="Mosque", validTarget=true}, --
  {typeName = "MOHAMMAD", description ="Mosque (Big and tall)"}, --Indestructible -Unique
  {typeName = "NICOSIA_KYKKOS_MONASTERY", description ="Monastery (Big)"}, --Indestructible -Unique
  {typeName = "NICOSIA_SELIMIYE_II_MOSQUE", description ="Mosque (Big and tall)"}, --Indestructible -Unique
  {typeName = "NICOSIA_STSOPHIA_CHURCH", description ="Church (Big and tall)"}, --Indestructible -Unique
  {typeName = "OMEJADOV", description ="Church / Temple (Big and tall)"}, --Indestructible -Unique
  {typeName = "ORTHODOX_CHURCH_01", description ="Orthodox church (Big)"}, --Indestructible -Unique
  {typeName = "ORTHODOX_CHURCH_03", description ="Orthodox church (Big)"}, --Indestructible -Unique
  {typeName = "OUR_LADY_OF_LEBANON", description ="Statue / Marian shrine"}, --Indestructible -Unique
  {typeName = "SABANCHI", description ="Mosque (Big and tall)"}, --Indestructible -Unique
  {typeName = "SAINT_GEORGES", description ="Church (Big and tall)"}, --Indestructible -Unique
  {typeName = "SAINT_PAUL_BASILICA", description ="Basilica (Tall)"}, --Indestructible -Unique
  {typeName = "SANCTUAIRE_NOTRE_DAME_DU_LIBAN", description ="Modern church (Big and tall)"}, --Indestructible -Unique
  {typeName = "ST_MARYS_CATHEDRAL", description ="Cathedral"}, --Indestructible -Unique
}

SYRIA_SMALL_CIVILIAN_BUILDINGS_TYPENAMES = {
  {typeName = "AYIA_NAPA_BOOSTER", description ="Attraction (Tall)"}, --Indestructible? Unique?
  {typeName = "AYIA_NAPA_CAROUSEL", description ="Carousel"}, --Indestructible? Unique?
  {typeName = "AYIA_NAPA_LOOPINGSTAR", description ="Rollercaster"}, --Indestructible? Unique?
  {typeName = "AYIA_NAPA_SLING_SHOT", description ="Sling shot attraction (Tall)"}, --Indestructible? Unique?
  {typeName = "BEIRUT_CLOCKTOWER", description ="Clock tower (tall) "}, --Indestructible -Unique
  {typeName = "TUNNEL_RAIL_2LINE", description ="Tunnel entrance"}, --Indestructible -Road and Rail
  {typeName = "VENT_10", description ="Open air parking with vent and a shade on top"}, --Unique
}

SYRIA_BIG_BUILDINGS_TYPENAMES = {
  {typeName = "ADANA_01BURDA_1", description ="Shopping mall (Big)"}, --Indestructible -Unique
  {typeName = "ADANA_01BURDA_2", description ="Shopping mall (Big)"}, --Indestructible -Unique
  {typeName = "ADANA_GALLERIA", description ="Shopping mall"}, --Indestructible -Unique
  {typeName = "ADANA_PARK_AVM", description ="Shopping mall / Park (Big)"}, --Indestructible -Unique
  {typeName = "ADANA_OPTIMUM", description ="Shopping mall (Big)"}, --Indestructible -Unique
  {typeName = "AL_ASSAD_LIBRARY", description ="Multifloor building / library"}, --Indestructible -Unique
  {typeName = "ALALBAYTUNIVERSITY", description ="O shaped building with multifloor building inside"}, --Indestructible? Unique?
  {typeName = "ALEPPO_CITY_HALL", description ="25+ floor with tower on top"}, --Indestructible -Unique
  {typeName = "ASAD_BUILDING", description ="Multi floor presidential palace"}, --Indestructible -Unique
  {typeName = "BANK", description ="Multiple linked multifloors building"}, --Indestructible? Unique? No valid ID from others building
  {typeName = "BANK_OF_CYPRUS", description ="Multifloor skycraper with helipad on top"}, --Indestructible -Unique
  {typeName = "BEIRUT_CHOUEIFAT_MALL", description ="Shopping mall (Big)"}, --Indestructible -Unique
  {typeName = "BEIRUT_SKYGATE", description ="Multifloor skycraper with helipad on top"}, --Indestructible -Unique
  {typeName = "CONSTRUCTION2", description ="WIP 15+ building", validTarget=true}, --
  {typeName = "CYPRUS_MINISTRY_OF_FINANCE", description ="5 floor building with solar panel on top"}, --Indestructible -Unique
  {typeName = "CYPRUS_TELECOMMUNICATIONS_AUTHORITY", description ="Multifloor key shaped building"}, --Indestructible -Unique  
  {typeName = "CYPRUS_SKYSCRAPER", description ="16 floor skycraper with helipad on top"}, --Indestructible -Unique
  {typeName = "DAGON", description ="Multifloor warehouse"}, --Haifa port multifloor warehouse - Indestructible? Unique?
  {typeName = "DAMASCUS_CONVENTION_CENTER1", description ="5 floor Y-shaped building part with 2/3 floor buildings around"}, --Indestructible -Unique
  {typeName = "DAMASCUS_CONVENTION_CENTER2", description ="5 floor Y-shaped building part with 2/3 floor buildings around"}, --Indestructible -Unique
  {typeName = "DAMASCUS_CONVENTION_CENTER3", description ="5 floor Y-shaped building part with 2/3 floor buildings around"}, --Indestructible -Unique
  {typeName = "DAMASCUS_CONVENTION_CENTER4", description ="5 floor Y-shaped building part with 2/3 floor buildings around"}, --Indestructible -Unique
  {typeName = "DAMASCUS_CONVENTION_CENTER5", description ="5 floor Y-shaped building part with 2/3 floor buildings around"}, --Indestructible -Unique
  {typeName = "DAMASCUS_CONVENTION_CENTER6", description ="5 floor Y-shaped building with 2/3 floor buildings around"}, --Indestructible -Unique
  {typeName = "DAMASCUS_GLASSHOUSE", description ="Multifloor complex "}, --Indestructible -Unique
  {typeName = "DAMASCUS_MASSAR_CENTRE", description ="Multifloor architectural museum in construction"}, --Indestructible -Unique
  {typeName = "DAMASCUS_MINISTRY_DEFENSE", description ="Multifloor open U-shaped building"}, --Indestructible -Unique
  {typeName = "DAMASCUS_OPERA_HOUSE", description ="Big Opera house"}, --Only in Damascus? --Indestructible -Unique
  {typeName = "DAMASCUS_RADIO_TV", description ="7/8 floor building with windows and small radio tower on top"}, --Indestructible -Unique
  {typeName = "DAMASCUS_TOWER", description ="White SQNY Tower (Tall)"}, --Indestructible -Unique
  {typeName = "DAMASCUS_UNKNOWN_SOLDIER", description ="Monument with a big sphere and arch above"}, --Indestructible -Unique
  {typeName = "FORTYFOURTOWERLEBANON", description ="Work in progress 42 floor skyscraper"}, --Indestructible -Unique
  {typeName = "FOUNTAIN", description ="Fountain monument (Big)"}, --Indestructible -Unique
  {typeName = "HAIFA_BAHAI_TRAININGCENTER", description ="Semi circular two floor building with columns (Big)"}, --Indestructible -Unique
  {typeName = "HAIFA_BAHAI_UNIVERSALHOUSEOFJUSTICE", description ="House of justice with cyan roof and columns all around"}, --Indestructible -Unique
  {typeName = "HAIFA_BUS_STATION", description ="Multifloor buliding with bus stations on one side"}, --Indestructible -Unique
  {typeName = "HAIFA_TOWER_PANORAMA", description ="Tower (Very tall)"}, --Indestructible -Unique
  {typeName = "HAIFA_TOWER_SAIL", description ="20+ floor skycraper"}, --Indestructible -Unique
  {typeName = "HAIFA_UNIVERSITY_DEPARTMENTS", description ="Multiple 5 floors university buildings"}, --Indestructible -Unique
  {typeName = "HAIFA_UNIVERSITY_JACOBSBUILDING", description ="3 floor building"}, --Indestructible -Unique
  {typeName = "HAIFA_UNIVERSITY_MAINBUILDING", description ="Multifloor building with long 2 floor building linked"}, --Indestructible -Unique
  {typeName = "HAIFA_UNIVERSITY_PARKING", description ="Multifloor building with long 2 floor building linked"}, --Indestructible -Unique No visual identification of target
  {typeName = "HOTEL_BASE_01", description ="3 floor Hotel (Large and long)"}, --Indestructible? Barracks?
  {typeName = "HOTEL_BASE_02", description ="4 floor hotel (Large and long)"}, --Barracks?
  {typeName = "HOTEL_BASE_04", description ="Two floor Hotel (Large and long)"}, --Indestructible? Barracks?
  {typeName = "KINGHUSSEINGATE", description ="King Hussein gate with domes"}, --Indestructible -Unique
  {typeName = "LIGHT1", description ="Mutifloor stadium light (Tall)"}, --
  {typeName = "LIMASOL_MYMALL", description ="Shopping Mall (Big)"}, --Indestructible -Unique
  {typeName = "MALL_OF_CYPRUS&IKEA", description ="Two 4/5 floors mall with one painted dark blue and bright yellow"}, --Indestructible? Unique?
  {typeName = "MINISTRY", description ="10 floors O-shaped building"}, --Indestructible -Unique
  {typeName = "NICOSIA_PRESIDENTIAL_PALACE", description ="2/3 floor Presidential palace with swimming pool "}, --Indestructible -Unique
  {typeName = "OVAL", description ="10+ Oval shaped building"}, --Indestructible -Unique
  {typeName = "PAPHOS_KINGS_AVENUE_MALL", description ="Multifloor slightly L-shaped mall"}, --Indestructible -Unique
  {typeName = "PLATINUMTOWERBEIRUT", description ="30+ floor skycraper"}, --Indestructible -Unique
  {typeName = "SAMA_BEIRUT", description ="40+ floor windows skycraper"}, --Indestructible -Unique
  {typeName = "SCOREBOARD", description ="Big stadium multifloor scoreboard"}, --Indestructible? Unique?
  {typeName = "STADIUMELEMENT", description ="Stadium element (Big)"}, --Indestructible?
  {typeName = "STADIUM_ROUND", description ="Stadium round part (Big)", validTarget=true},
  {typeName = "STADIUM_STRAIGHT", description ="Stadium straight part (Long)", validTarget=true}, --
  {typeName = "STAR", description ="Star monument with a tall flag pole"}, --Indestructible -Unique
  {typeName = "VEGAS_PARKING_01", description ="5/6 floor parking building (Big and tall)"}, --Indestructible
  {typeName = "VIC_ARENA1", description ="Football stadium part"}, --Indestructible? Unique?
  {typeName = "VIC_ARENA2", description ="Football stadium part"}, --Indestructible? Unique?
  {typeName = "VIC_ARENA3", description ="Football stadium part"}, --Indestructible? Unique?
  {typeName = "VIC_ARENA4", description ="Football stadium part"}, --Indestructible? Unique?
}


SYRIA_SMALL_INDUSTRIAL_TARGETS_TYPENAMES = {
  {typeName = "ATATURKA_PIPES", description ="8 dam pipes (Long)"}, --Indestructible -Unique
  {typeName = "CABIN", description ="Container cabin (Small)", validTarget=true},
  {typeName = "CABIN2", description ="Container cabin (Small)", validTarget=true},
  {typeName = "DSISIGN", description ="DSI sign on DAM"}, --Indestructible? Unique?
  {typeName = "GASOILPIPEHANDLER", description ="Gasoil pipe handler (Small)"}, --Indestructible and too many linked to make a valid industrial target
  {typeName = "INDUSTRIAL_CONTAINER_02", description ="Industrial containers (2 floor tall)", validTarget=true},
  {typeName = "POWER_TRANS_LINE_BIG", description ="Power pylon (Tall)"}, -- Tall power pylons --Too many in lines to make a valid industrial target
  {typeName = "TUBE_PILE", description ="Stack of 6 long 1 meter diameter tubes", validTarget=true}, --
}

SYRIA_INDUSTRIAL_TARGETS_TYPENAMES = {
  {typeName = "ALEPPO_ELECTROSTATION", description ="One floor building without windows or doors (Long)"}, --indestructible ? Unique?
  {typeName = "ALEPPO_ELECTROSTATION_ELEMENT1", description ="One floor building with 6 big fans exhausts on top (Long)"}, --indestructible ? Unique?
  {typeName = "ALEPPO_ELECTROSTATION_ELEMENT2", description ="One floor building without windows or doors (Long)"}, --indestructible ? Unique?
  {typeName = "BENGAL_POWER_HUB", description ="Power hub (small)", validTarget=true}, --
  {typeName = "CEMENTFACTORY_BUILDING", description ="Cement factory buildings with chimneys and linked by 4 long big pipes"}, --indestructible ?
  {typeName = "DAM1", description ="Dam (Large)"}, --Indestructible -Unique
  {typeName = "DAM_TISHRIN", description ="Dam (Large)"}, --Indestructible -Unique
  {typeName = "ELEVATOR_BUILDING01", description ="Multifloor factory with a tall tower (Big)"}, --Indestructible? Unique?
  {typeName = "ELEVATOR_BUILDING02", description ="Double linked multifloor factory with a tall tower (Big)"}, --Indestructible? Unique?
  {typeName = "ELEVATOR_HOUSE01_BUILDING", description ="Multifloor factory with a tall tower (Big)"}, --Indestructible? Unique?
  {typeName = "ELEVATOR_HOUSE02_BUILDING", description ="Multifloor factory with a tall tower (Big)"}, --Indestructible? Unique?
  {typeName = "HAIFA_COOLINGTOWERS", description ="Cooling towers (Tall)"}, --Indestructible? Unique?
  {typeName = "INDUSTRIAL_CONTAINER_01", description ="Industrial containers (3 floor tall) ", validTarget=true},
  {typeName = "LAFARGE_CEMENT_FACTORY0", description ="Cement factory part"}, --Indestructible -Unique
  {typeName = "LAFARGE_CEMENT_FACTORY1", description ="Cement factory part"}, --Indestructible -Unique
  {typeName = "LAFARGE_CEMENT_FACTORY2", description ="Cement factory part"}, --Indestructible -Unique
  {typeName = "LAFARGE_CEMENT_FACTORY3", description ="Cement factory part"}, --Indestructible -Unique
  {typeName = "LAFARGE_CEMENT_FACTORY4", description ="Cement factory part"}, --Indestructible -Unique
  {typeName = "LAFARGE_CEMENT_FACTORY5", description ="Cement factory part with big and tall pipes"}, --Indestructible -Unique
  {typeName = "LAFARGE_CEMENT_FACTORY7", description ="Cement factory part"}, --Indestructible -Unique
  {typeName = "LAFARGE_CEMENT_FACTORY8", description ="Cement factory part with blue top and a big chimney"}, --Indestructible -Unique
  {typeName = "LAFARGE_CEMENT_FACTORY9", description ="Cement factory part with long open warehouse with blue roof"}, --Indestructible -Unique
  {typeName = "LIMASOL_KEAN_FACTORY", description ="Multi one floor yellow warehouses/factories"}, --Indestructible? Unique?
  {typeName = "NDB_HIGH_TOWER", description ="NDB Communication tower (Tall)", validTarget=true}, --
  {typeName = "OILGAS_REFINERY_01", description ="Multiple floor oil gas refinery", validTarget=true}, --
  {typeName = "OILGAS_REFINERY_02", description ="Multiple floor oil gas refinery building with windows", validTarget=true}, --
  {typeName = "OILGAS_REFINERY_03", description ="Two floor oil gas refinery with a cooling tower on top (Small)", validTarget=true}, --
  {typeName = "OILGAS_REFINERY_04", description ="Multiple floor oil gas refinery", validTarget=true}, --
  {typeName = "OILGAS_REFINERY_05", description ="One floor gas refinery (Small)", validTarget=true}, --
  {typeName = "POWER_PLANT_01", description ="3 floor power plant with two tall chimey", validTarget=true}, --
  {typeName = "POWER_TRANS_STATION", description ="Power transformation station", validTarget=true}, --
  {typeName = "SOLAR_PANEL_LARGE", description ="Solar panel (Large)", validTarget=true}, --
  {typeName = "SOLAR_PANEL_SMALL", description ="Solar panel", validTarget=true}, --
  {typeName = "WINDGEN", description ="Wind turbine (Tall)"}, --Tall wind turbine indestructible??
  {typeName = "WINDGEN_OFF", description ="Wind turbine stopped (Tall)"}, --Tall wind turbine stopped indestructible??
}

SYRIA_WATER_TOWER_TYPENAMES = {
}

SYRIA_CIVIL_VEHICLES_TYPENAMES = {
  {typeName = "BUS_NAN", description ="Yellow modern double deck bus", validTarget=true}, --
  {typeName = "FISHINGBOAT_01", description ="Wooden fishing boat", validTarget=true}, --
}

SYRIA_MILITARY_TARGETS_TYPENAMES = {
  {typeName = "BUNKERHILL", description ="Hill above buker (Small)"}, --
  {typeName = "TANKCOVER", description ="Tank cover"}, --
  {typeName = "TANKCOVER2", description ="Tank cover"}, --
}

SYRIA_LIGHTHOUSE_TYPENAMES = {
  {typeName = "LIGHTHOUSE", description ="Lighthouse", validTarget=true}, --
}

SYRIA_DEBRIS_TYPENAMES = {
  {typeName = "AZAL_OIL_TANK_CRASH", description ="Oil tank debris"}, --Unique?
  {typeName = "BEAMS_CRASH", description ="Beam debris"}, --Unique?
  {typeName = "BEAMS_CRASH_02", description ="Beam debris"}, --Unique?
  {typeName = "BOARD_CRASH", description ="Board debris"}, --Unique?
  {typeName = "CAR_CRASH_01", description ="Car debris"}, --Indestructible? Unique?
  {typeName = "CONTAINER_CRASH", description ="Container debris"}, --Unique?
  {typeName = "COTTAGE_02_CRASH", description ="Cottage debris"}, --Unique?
  {typeName = "COTTAGE_03_CRASH", description ="Cottage debris"}, --Unique?
  {typeName = "COTTAGE_04_CRASH", description ="Cottage debris"}, --Unique?
  {typeName = "CRASHCOLUMM_Y", description ="Building debris"}, --
  {typeName = "DEBRIS_CONCRETE_01", description ="Concrete debris"}, --
  {typeName = "DIESEL_GENERATOR_CRASH", description ="Diesel generator debris"}, --
  {typeName = "FENCE_WALL_CRASH", description ="Destroyed fenced wall debris"}, --
  {typeName = "HUNGAR_023_CRASH", description ="Destroyed hangar debris"}, --Unique - INVALID
  {typeName = "HUNGAR_05_CRASH", description ="Destroyed hangar debris"}, --
  {typeName = "ROAD_RAMP_CRASH", description ="Road ramp debris"}, --2 isntances close from each other
  {typeName = "SMALL_CRASH", description ="Car junk (Small)"}, --
  {typeName = "TRUCK_CRASH_01", description ="Truck debris"}, --Unique?
  {typeName = "TRUCK_CRASH_02", description ="Truck debris"}, --Unique?
}

strategicTargetDestroyedList = {}

strategicTargetDestroyedEventHandler = {}

strategicTargetsChoiceDone = false

function strategicTargetDestroyedEventHandler:onEvent(event)
  if event.id == world.event.S_EVENT_DEAD then
    --env.info (tprint(event))     
    if event.initiator ~= nil then
      env.info (" S_EVENT_DEAD - event.initiator['id_'] : " .. event.initiator['id_'])
      table.insert(strategicTargetDestroyedList, event.initiator['id_'])   
      
      local noMoreStrategicTarget = false
      for i,currentStrategicTarget in pairs(strategicTargetList) do
          local currentStrategicTargetName = currentStrategicTarget['name']
          if currentStrategicTargetName == event.initiator['id_'] then
          --One strategic target has been destroyed so we removed it from the list so we don't call a strike on it later
            index = i
            table.remove( strategicTargetList, i )
            
            --Check if the strategic target is part of the current strike target
            local count = 0
            for j,currentTarget in pairs(strategicTargets) do
              count = count + 1
              local currentTargetName = currentTarget['name']
              if currentTargetName == event.initiator['id_'] then
                --It's part of our current strike and destroyed so we notify and removed it from the current strike available targets list
                local typeName = currentTarget['desc']['typeName']
                local extendedDescription = getSceneryObjectExtendedDescription(typeName)
                trigger.action.outTextForCoalition(dispatcherCoalition,"TARGET DESTROYED : " .. extendedDescription , 60 , false)
                env.info("TARGET DESTROYED : " .. extendedDescription)
                table.remove( strategicTargets, j )
                count = count - 1
              end
            end
        
            if count == 0 then
              noMoreStrategicTarget = true
            end
            
            break
          end
      end
      
      if noMoreStrategicTarget and strategicTargetsChoiceDone then
        --Better management between all targets destroyed and new strategic target selected so we dont display this twice
        strategicTargetsChoiceDone = false
        
        trigger.action.outTextForCoalition(dispatcherCoalition,"ALL TARGETS IN THE AREA ARE DESTROYED" , 60 , false)
        env.info("ALL TARGETS IN THE AREA ARE DESTROYED")
        COORDINATE:RemoveMark(strategicTargetMarkId)
        scheduleChooseNextStrategicTarget(5)
      end
    end
  end
end

world.addEventHandler(strategicTargetDestroyedEventHandler)

function scheduleChooseNextStrategicTarget(delay)
  timer.scheduleFunction(chooseNextStrategicTarget, nil, timer.getTime() + delay )    
end

function skipChooseNextStrategicTarget(delay)
  trigger.action.outTextForCoalition(dispatcherCoalition,"CURRENT STRATEGIC TARGETS STRIKE SKIPPED - WAIT FOR FURTHER ORDERS" , 60 , false)
  env.info("CURRENT STRATEGIC TARGETS STRIKE SKIPPED - WAIT FOR FURTHER ORDERS")
  COORDINATE:RemoveMark(strategicTargetMarkId)
  scheduleChooseNextStrategicTarget(delay)
end

function checkForStrategicTargetType(foundUnit, pattern, table, debug)
   if foundUnit['desc']['typeName']:find(pattern) ~= nil then
    table[#table + 1] = foundUnit
    local extendedDescription = getSceneryObjectExtendedDescription(foundUnit['desc']['typeName'])
    if debug then
      env.info ("checkForStrategicTargetType typeName: " .. foundUnit['desc']['typeName'] .. " - extendedDescription: " .. extendedDescription .. " found")
      env.info (tprint(foundUnit))
    end
  end
end

function getLocalStrategicTargetsInArea(currentTarget, maxDistance)
  localStrategicTargetsInArea = {}
  --env.info("getLocalStrategicTargetsInArea start")
  local currentTargetName = currentTarget['name']
  --env.info("getLocalStrategicTargetsInArea currentTargetName : " .. currentTargetName)
  local targetWP = {x = currentTarget.x, y = currentTarget.y , z = currentTarget.z}
  currentTargetCoordinate = COORDINATE:NewFromVec3(targetWP)
  for i,otherTarget in pairs(strategicTargetList) do
    local otherTargetName = otherTarget['name']
    --env.info("getLocalStrategicTargetsInArea otherTargetName : " .. otherTargetName)
    if otherTargetName == currentTargetName
      or has_value(strategicTargets, otherTarget) then
      --Same object or already added or destroyed so we don't care
    else
      --local scenery=otherTarget --Wrapper.Scenery#SCENERY
      local otherTargetWP = {x = otherTarget.x, y = otherTarget.y , z = otherTarget.z}
      local otherTargetCoordinate= COORDINATE:NewFromVec3(otherTargetWP)
      local distance=currentTargetCoordinate:Get2DDistance(otherTargetCoordinate)
      --env.info("getLocalStrategicTargetsInArea distance : " .. math.floor(distance + 0.5) .. " meters")
      if distance< maxDistance then
        table.insert(localStrategicTargetsInArea, otherTarget)
      end
    end
  end
  --env.info("getLocalStrategicTargetsInArea end")
end

function checkForAdditionalStrategicTargetsInArea(currentTarget, maxDistance)
  --env.info("checkForAdditionalStrategicTargetsInArea start")
  local currentTargetName = currentTarget['name']
  --env.info("checkForAdditionalStrategicTargetsInArea currentTargetName : " .. currentTargetName)
  local targetWP = {x = currentTarget.x, y = currentTarget.y , z = currentTarget.z}
  currentTargetCoordinate = COORDINATE:NewFromVec3(targetWP)

  if localStrategicTargetsInArea then
    for i,otherTarget in pairs(localStrategicTargetsInArea) do
      local otherTargetName = otherTarget['name']
      --env.info("checkForAdditionalStrategicTargetsInArea otherTargetName : " .. otherTargetName)
      if otherTargetName == currentTargetName
        or has_value(strategicTargets, otherTarget) then
        --Same object or already added or destroyed so we don't care
      else
        --local scenery=otherTarget --Wrapper.Scenery#SCENERY
        local otherTargetWP = {x = otherTarget.x, y = otherTarget.y , z = otherTarget.z}
        local otherTargetCoordinate= COORDINATE:NewFromVec3(otherTargetWP)
        local distance=currentTargetCoordinate:Get2DDistance(otherTargetCoordinate)
        --env.info("checkForAdditionalStrategicTargetsInArea distance : " .. math.floor(distance + 0.5) .. " meters")
        if distance< maxDistance then
          table.insert(strategicTargets, otherTarget)
          --trigger.action.outTextForCoalition(dispatcherCoalition,"ADDITIONAL TARGET FOUND : " .. otherTarget['desc']['typeName'] .. " at " .. math.floor(distance + 0.5) .. " meters", 60)
          --env.info("ADDITIONAL TARGET FOUND : " .. otherTarget['desc']['typeName'] .. " at " .. math.floor(distance + 0.5) .. " meters")
          checkForAdditionalStrategicTargetsInArea(otherTarget, maxDistance)
        end
      end
    end
  end
  
  --env.info("checkForAdditionalStrategicTargetsInArea end")
end

function getTargetAreaInfo(debug)
  local targetAreaInfo = {}
  
  local x = 0
  local y = 0
  local z = 0
  local extendedDescriptions = {}
  
  for i,target in pairs(strategicTargets) do
    x = x + target.x
    y = y + target.y
    z = z + target.z
    
    local typeName = target['desc']['typeName']
    local extendedDescription = getSceneryObjectExtendedDescription(typeName)
    
    local descriptionFound = false
    
    for j,description in pairs(extendedDescriptions) do
      local descriptionText = description.text
      if descriptionText == extendedDescription then
        descriptionFound = true        
        extendedDescriptions[j].count = description.count + 1
        break
      end
    end
    if not descriptionFound then
      table.insert(extendedDescriptions, {text = extendedDescription, typeName = typeName, count = 1})
    end
    
    if debug then
      if targetDebugging then
        --Debug features to have a quick look on a scenery object before destroying it
        local targetWP = {x = target.x, y = target.y , z = target.z}
        spawnInfantrySquad(targetWP)
        timer.scheduleFunction(explodeThis, targetWP, timer.getTime() + 10 + i )
      end
    end
  end
  
  x = x / #strategicTargets
  y = y / #strategicTargets
  z = z / #strategicTargets
  local targetAreaWP = {x = x, y = y , z = z}
  --local lat, long, alt = coord.LOtoLL(targetWP)
  --local coordSTRTarget = getCoordinatesSTR(lat, long) 
  
  targetAreaInfo.extendedDescriptions = extendedDescriptions
  targetAreaInfo.targetAreaWP = targetAreaWP
  
  if debug then
    --Debug features to have a quick look on a scenery object before destroying it
    --spawnInfantrySquad(targetAreaInfo.targetAreaWP)
  end
  
  return targetAreaInfo
end

function markStrategicTargets()
  
  local targetAreaInfo = getTargetAreaInfo(true)

  local lat, long, alt = coord.LOtoLL(targetAreaInfo.targetAreaWP)
  local coordSTRTarget = getCoordinatesSTR(lat, long)
  targetAreaCoordinate = COORDINATE:NewFromVec3(targetAreaInfo.targetAreaWP)
    
  local markText = "TARGET AREA : " .. coordSTRTarget.lat .. "     " .. coordSTRTarget.long
  for j,description in pairs(targetAreaInfo.extendedDescriptions) do
    markText = markText .. "\n" .. description.text .. " x " .. description.count
  end
  
  if dispatcherCoalition == coalition.side.BLUE then
    strategicTargetMarkId = targetAreaCoordinate:MarkToCoalitionBlue( markText, true, markText )
  elseif dispatcherCoalition == coalition.side.RED then
    strategicTargetMarkId = targetAreaCoordinate:MarkToCoalitionRed( markText, true, markText )
  end
        
  --[[
  strategicTargetCoordinate = COORDINATE:NewFromVec3(targetWP)
  local markText = "Target: " .. extendedDescription
  strategicTargetMarkId = strategicTargetCoordinate:MarkToCoalitionBlue( markText, true, markText )
  
  --Debug features to have a quick look on a scenery object before destroying it
  --env.info(tprint(target))
  --spawnInfantrySquad(targetWP)
  --timer.scheduleFunction(explodeThis, targetWP, timer.getTime() + 10)
  --]]
end

function chooseNextStrategicTarget()
  --Random item in the list
  strategicTarget = strategicTargetList[math.random(#strategicTargetList)]
  if strategicTarget then
    strategicTargets = {}
    table.insert(strategicTargets, strategicTarget)
    -- targets around a certain radius of current strategic target
    -- get first a list of local strategic target around the first one to not iterate through all the map for additional proximity strategic targets
    if targetDebugging == false then
      getLocalStrategicTargetsInArea(strategicTarget, 1000)
    end
    --trigger.action.outTextForCoalition(dispatcherCoalition,"localStrategicTargetsInArea: " .. #localStrategicTargetsInArea, 60)
    --env.info("localStrategicTargetsInArea: " .. #localStrategicTargetsInArea)
    
    --[[
    localStrategicTargetsInArea = {}
    local position = {x = strategicTarget.x, y = strategicTarget.z , z = strategicTarget.y}
    local sceneryObjectsInArea = findSceneryObjectsInCoordinatesAndRadius(position, 1000)
    trigger.action.outTextForCoalition(dispatcherCoalition,"sceneryObjectsInArea: " .. #sceneryObjectsInArea, 60)
    env.info("sceneryObjectsInArea: " .. #sceneryObjectsInArea)
    for i,sceneryObject in pairs(sceneryObjectsInArea) do
      if has_value(strategicTargetList, sceneryObject) and not has_value(strategicTargetDestroyedList, sceneryObject['name']) then
        insertInTableIfNew(localStrategicTargetsInArea, sceneryObject)
      end
    end
    --]]
    
    if targetDebugging == false then
      checkForAdditionalStrategicTargetsInArea(strategicTarget, 250)
    end
    
    --Mark the whole targets area
    markStrategicTargets()
  
    showStrategicTargetStrikeBriefing()
    
    strategicTargetsChoiceDone = true
  else
    trigger.action.outTextForCoalition(dispatcherCoalition,"NO MORE STRATEGIC TARGET IN THE OPERATIONAL AREA ", 60)
    env.info("NO MORE STRATEGIC TARGET IN THE OPERATIONAL AREA ")
  end 
    
  --[[
  --Next item in the list
  strategicTarget = strategicTargetList[strategicTargetCount]
  if strategicTarget then
    if has_value(strategicTargetDestroyedList, strategicTarget['name']) then
      strategicTargetCount = strategicTargetCount + 1
      chooseNextStrategicTarget()
    else
      --table.remove(target)
      showStrategicTargetStrikeBriefing()
      strategicTargetCount = strategicTargetCount + 1
    end
  end
  --]]
end

function getCaucasusSceneryObjectExtendedDescription(typeName)
  if has_typeName(CAUCASUS_AIRPORT_SMALL_OBJECTS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_AIRPORT_SMALL_OBJECTS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_AIRPORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_AIRPORT_STRATEGIC_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_PORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_PORT_STRATEGIC_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_OFFSHORE_OIL_RIG_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_OFFSHORE_OIL_RIG_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_RAILWAY_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_RAILWAY_STRATEGIC_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_RAILWAY_BRIDGES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_RAILWAY_BRIDGES_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_ROAD_BRIDGES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_ROAD_BRIDGES_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_TANKS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_TANKS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_VERY_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_VERY_SMALL_WAREHOUSES_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_SMALL_WAREHOUSES_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_MEDIUM_WAREHOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_MEDIUM_WAREHOUSES_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_BIG_WAREHOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_BIG_WAREHOUSES_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_HOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_HOUSES_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_HOUSES_BUILDINGS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_HOUSES_BUILDINGS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_SMALL_CIVILIAN_BUILDINGS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_SMALL_CIVILIAN_BUILDINGS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_BIG_BUILDINGS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_BIG_BUILDINGS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_HOSPITALS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_HOSPITALS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_HOTELS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_HOTELS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_OLD_BUILDINGS_RUINS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_OLD_BUILDINGS_RUINS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_RELIGIOUS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_RELIGIOUS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_SMALL_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_SMALL_INDUSTRIAL_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_INDUSTRIAL_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_WATER_TOWER_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_WATER_TOWER_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_MILITARY_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_MILITARY_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(CAUCASUS_LIGHTHOUSE_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(CAUCASUS_LIGHTHOUSE_TYPENAMES, typeName)
  else
      env.info("extendedDescription typeName : " .. typeName .. " not found in any category")
      extendedDescription = typeName        
  end
  
  return extendedDescription
end


function getSyriaSceneryObjectExtendedDescription(typeName)
  if has_typeName(SYRIA_AIRPORT_SMALL_OBJECTS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_AIRPORT_SMALL_OBJECTS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_AIRPORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_AIRPORT_STRATEGIC_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_PORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_PORT_STRATEGIC_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_OFFSHORE_OIL_RIG_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_OFFSHORE_OIL_RIG_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_RAILWAY_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_RAILWAY_STRATEGIC_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_RAILWAY_BRIDGES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_RAILWAY_BRIDGES_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_ROAD_BRIDGES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_ROAD_BRIDGES_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_TANKS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_TANKS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_VERY_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_VERY_SMALL_WAREHOUSES_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_SMALL_WAREHOUSES_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_MEDIUM_WAREHOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_MEDIUM_WAREHOUSES_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_BIG_WAREHOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_BIG_WAREHOUSES_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_HOUSES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_HOUSES_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_HOUSES_BUILDINGS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_HOUSES_BUILDINGS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_SMALL_CIVILIAN_BUILDINGS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_SMALL_CIVILIAN_BUILDINGS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_BIG_BUILDINGS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_BIG_BUILDINGS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_HOSPITALS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_HOSPITALS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_HOTELS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_HOTELS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_OLD_BUILDINGS_RUINS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_OLD_BUILDINGS_RUINS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_RELIGIOUS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_RELIGIOUS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_SMALL_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_SMALL_INDUSTRIAL_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_INDUSTRIAL_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_WATER_TOWER_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_WATER_TOWER_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_CIVIL_VEHICLES_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_CIVIL_VEHICLES_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_MILITARY_TARGETS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_MILITARY_TARGETS_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_LIGHTHOUSE_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_LIGHTHOUSE_TYPENAMES, typeName)
  elseif has_typeName(SYRIA_DEBRIS_TYPENAMES, typeName) then
    extendedDescription = getTableSceneryObjectExtendedDescription(SYRIA_DEBRIS_TYPENAMES, typeName)
  else
      env.info("extendedDescription typeName : " .. typeName .. " not found in any category")
      extendedDescription = typeName        
  end
  
  return extendedDescription
end

function getSceneryObjectExtendedDescription(typeName)
  local extendedDescription
  
  if theatre == "Caucasus" then
    extendedDescription = getCaucasusSceneryObjectExtendedDescription(typeName)
  --elseif theatre == "Nevada" then
  --elseif theatre == "Normandy" then
  elseif theatre == "Syria" then
    extendedDescription = getSyriaSceneryObjectExtendedDescription(typeName)
  else 
    trigger.action.outText("No SceneryObjectExtendedDescription yet for theatre: " .. theatre, 120)
    env.info("No SceneryObjectExtendedDescription yet for theatre: " .. theatre)
  end
  
  
  
  return extendedDescription
end

function getTableSceneryObjectExtendedDescription(table, typeName)
  for index, value in ipairs(table) do
    if value.typeName == typeName then
      return value.description
    end
  end
end

function showStrategicTargetStrikeBriefing()
  if #strategicTargets > 0 then    
  
    local targetAreaInfo = getTargetAreaInfo(false)
  
    local lat, long, alt = coord.LOtoLL(targetAreaInfo.targetAreaWP)
    local coordSTRTarget = getCoordinatesSTR(lat, long)
    
    targetAreaCoordinate = COORDINATE:NewFromVec3(targetAreaInfo.targetAreaWP)
    local text = "TARGET AREA : " .. coordSTRTarget.lat .. "     " .. coordSTRTarget.long
    local debugText = "TARGET AREA : " .. coordSTRTarget.lat .. "     " .. coordSTRTarget.long
    for j,description in pairs(targetAreaInfo.extendedDescriptions) do
      text = text .. "\n" .. description.text .. " x " .. description.count 
      debugText = debugText .. "\n" .. description.typeName .. " - " .. description.text .. " x " .. description.count .. "\n"
    end
    
    trigger.action.outTextForCoalition(dispatcherCoalition,text, 120)
    env.info(debugText)
  end
end

function insertNonCategorizedFoundUnitInStrategicTargetListIfNeeded(foundUnit)
  local typeName = foundUnit['desc']['typeName']
  
  --debug code in order to see what our non categorized scenery objects looks like and trigger only one warning for a typeName
  --env.info (tprint(foundUnit))
  if not has_value(notFoundTypeNameList, typeName) then
    if typeName then
      -- [[
      if targetDebugging then
        forceInsertInStrategicTargetList(foundUnit)
      end
      --]]
      insertInTableIfNew(notFoundTypeNameList, typeName)
      env.info("insertNonCategorizedFoundUnitInStrategicTargetListIfNeeded typeName : " .. typeName .. " not found in any category")
    else
      env.info("insertNonCategorizedFoundUnitInStrategicTargetListIfNeeded null typeName found")
    end
  end
  --[[
  --debug code to display all non categorized scenery objects
  if typeName and targetDebugging then
    forceInsertInStrategicTargetList(foundUnit)
  end
  --]]  
end

function insertCaucasusFoundUnitInStrategicTargetListIfNeeded(foundUnit)
  local typeName = foundUnit['desc']['typeName']
  -- do nothing if not suitable or too small to check
  if has_typeName(CAUCASUS_AIRPORT_SMALL_OBJECTS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_AIRPORT_SMALL_OBJECTS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_AIRPORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_AIRPORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_PORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_PORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_OFFSHORE_OIL_RIG_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_OFFSHORE_OIL_RIG_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_RAILWAY_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_RAILWAY_STRATEGIC_TARGETS_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_RAILWAY_BRIDGES_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_RAILWAY_BRIDGES_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_ROAD_BRIDGES_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_ROAD_BRIDGES_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_TANKS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_TANKS_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_VERY_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_VERY_SMALL_WAREHOUSES_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_SMALL_WAREHOUSES_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_MEDIUM_WAREHOUSES_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_MEDIUM_WAREHOUSES_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_BIG_WAREHOUSES_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_BIG_WAREHOUSES_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_HOUSES_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_HOUSES_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_HOUSES_BUILDINGS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_HOUSES_BUILDINGS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_SMALL_CIVILIAN_BUILDINGS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_SMALL_CIVILIAN_BUILDINGS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_BIG_BUILDINGS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_BIG_BUILDINGS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_HOSPITALS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_HOSPITALS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_HOTELS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_HOTELS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_OLD_BUILDINGS_RUINS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_OLD_BUILDINGS_RUINS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_RELIGIOUS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_RELIGIOUS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_SMALL_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_SMALL_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_WATER_TOWER_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_WATER_TOWER_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_MILITARY_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_MILITARY_TARGETS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(CAUCASUS_LIGHTHOUSE_TYPENAMES, typeName) then
    if isValidTarget(CAUCASUS_LIGHTHOUSE_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  else
    insertNonCategorizedFoundUnitInStrategicTargetListIfNeeded(foundUnit)
  end
end

function insertSyriaFoundUnitInStrategicTargetListIfNeeded(foundUnit)
  local typeName = foundUnit['desc']['typeName']
  -- do nothing if not suitable or too small to check
  if has_typeName(SYRIA_AIRPORT_SMALL_OBJECTS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_AIRPORT_SMALL_OBJECTS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_AIRPORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_AIRPORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_PORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_PORT_STRATEGIC_TARGETS_TYPENAMES, typeName) then
      --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_OFFSHORE_OIL_RIG_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_OFFSHORE_OIL_RIG_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_RAILWAY_STRATEGIC_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_RAILWAY_STRATEGIC_TARGETS_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_RAILWAY_BRIDGES_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_RAILWAY_BRIDGES_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_ROAD_BRIDGES_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_ROAD_BRIDGES_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_TANKS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_TANKS_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_VERY_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_VERY_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_SMALL_WAREHOUSES_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_MEDIUM_WAREHOUSES_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_MEDIUM_WAREHOUSES_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_BIG_WAREHOUSES_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_BIG_WAREHOUSES_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_HOUSES_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_HOUSES_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_HOUSES_BUILDINGS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_HOUSES_BUILDINGS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_SMALL_CIVILIAN_BUILDINGS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_SMALL_CIVILIAN_BUILDINGS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_BIG_BUILDINGS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_BIG_BUILDINGS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_HOSPITALS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_HOSPITALS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_HOTELS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_HOTELS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_OLD_BUILDINGS_RUINS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_OLD_BUILDINGS_RUINS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_RELIGIOUS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_RELIGIOUS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_SMALL_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_SMALL_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_INDUSTRIAL_TARGETS_TYPENAMES, typeName) then
      insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_WATER_TOWER_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_WATER_TOWER_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_CIVIL_VEHICLES_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_CIVIL_VEHICLES_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_MILITARY_TARGETS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_MILITARY_TARGETS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_LIGHTHOUSE_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_LIGHTHOUSE_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  elseif has_typeName(SYRIA_DEBRIS_TYPENAMES, typeName) then
    if isValidTarget(SYRIA_DEBRIS_TYPENAMES, typeName) then
    --insertInStrategicTargetList(foundUnit)
    end
  else
    insertNonCategorizedFoundUnitInStrategicTargetListIfNeeded(foundUnit)
  end
end

function insertFoundUnitInStrategicTargetListIfNeeded(foundUnit)  
  if theatre == "Caucasus" then
    insertCaucasusFoundUnitInStrategicTargetListIfNeeded(foundUnit)
  --elseif theatre == "Nevada" then
  --elseif theatre == "Normandy" then
  elseif theatre == "Syria" then
    insertSyriaFoundUnitInStrategicTargetListIfNeeded(foundUnit)
  else 
    trigger.action.outText("No compatibility yet for theatre: " .. theatre, 120)
    env.info("No compatibility yet for theatre: " .. theatre)
  end
end

--STRATEGIC TARGET END

function findSceneryObjectsInCoordinatesAndRadius(position, radius)
  env.info("findSceneryObjectsInCoordinatesAndRadius start")
 
  local foundUnits = {}
  
  local volS = {
    id = world.VolumeType.SPHERE,
    params = {
    point = position,
    radius = radius
    }
  }
   
  local ifFound = function(foundItem, val)
    --foundUnits[#foundUnits + 1] = foundItem:getName()

    local index = #foundUnits + 1
    foundUnits[index] = {}
    if foundItem:getDesc() ~= nil then    
      foundUnits[index]['desc'] = foundItem:getDesc()
    end
    if foundItem:getName() ~= nil then    
      foundUnits[index]['name'] = foundItem:getName()
    end
    if foundItem:getPoint() ~= nil then
      foundUnits[index]['x'] = foundItem:getPoint().x
      foundUnits[index]['y'] = foundItem:getPoint().y
      foundUnits[index]['z'] = foundItem:getPoint().z
    end
    return true
  end
   
   --world.searchObjects(Object.Category.UNIT, volS, ifFound)
   world.searchObjects(Object.Category.SCENERY, volS, ifFound)
  
  env.info("findSceneryObjectsInCoordinatesAndRadius end")
  
  return foundUnits
end

function findSceneryObjectsInTriggerZone(triggerZoneName)
  env.info("findSceneryObjectsInTriggerZone : " .. triggerZoneName .. " start")
 
  local foundUnits = {}
  
  local sphere = trigger.misc.getZone(triggerZoneName)
  if sphere then
    local volS = {
      id = world.VolumeType.SPHERE,
      params = {
      point = sphere.point,
      radius = sphere.radius
      }
    }
     
    local ifFound = function(foundItem, val)
      --foundUnits[#foundUnits + 1] = foundItem:getName()
  
      local index = #foundUnits + 1
      foundUnits[index] = {}
      if foundItem:getDesc() ~= nil then    
        foundUnits[index]['desc'] = foundItem:getDesc()
      end
      if foundItem:getName() ~= nil then    
        foundUnits[index]['name'] = foundItem:getName()
      end
      if foundItem:getPoint() ~= nil then
        foundUnits[index]['x'] = foundItem:getPoint().x
        foundUnits[index]['y'] = foundItem:getPoint().y
        foundUnits[index]['z'] = foundItem:getPoint().z
      end
      return true
    end
     
    --world.searchObjects(Object.Category.UNIT, volS, ifFound)
    world.searchObjects(Object.Category.SCENERY, volS, ifFound)
     
    for i, foundUnit in ipairs(foundUnits) do
      if foundUnit then
        insertFoundUnitInStrategicTargetListIfNeeded(foundUnit)     
        --checkForStrategicTargetType(foundUnit, "MOST", strategicTargetList, true)
      end
    end
  else
    trigger.action.outText("No zone found for zoneName: " .. triggerZoneName, 30)
    env.info("No zone found for zoneName: " .. triggerZoneName)
  end

  env.info("findSceneryObjectsInTriggerZone : " .. triggerZoneName .. " end")
end

function addCircularZone(zoneName)
  if not has_value(zoneList, zoneName) then
    insertInTableIfNew(zoneList, zoneName)
  end
end

dispatcherCoalition = coalition.side.BLUE
function setDispatcherForBlueCoalition()
  dispatcherCoalition = coalition.side.BLUE
end

function setDispatcherForRedCoalition()
  dispatcherCoalition = coalition.side.RED
end

function startDispatcher()
  theatre = env.mission.theatre
  --trigger.action.outText("Theatre: " .. theatre, 120)
  --env.info("Theatre: " .. theatre)
  
  for i, zoneName in ipairs(zoneList) do
    findSceneryObjectsInTriggerZone(zoneName)
  end
  
  chooseNextStrategicTarget()
   
  --findSceneryObjectsInTriggerZone("targetZone")
  --findSceneryObjectsInTriggerZone("InterceptZone")
  --findSceneryObjectsInTriggerZone("testZone")
  
  if strategicTarget then
    menuStrategicTargetsStrike = missionCommands.addSubMenuForCoalition(dispatcherCoalition , 'Strategic targets strike')
    menuCommandStrategicTargetsStrikeBriefing = missionCommands.addCommandForCoalition(dispatcherCoalition , 'Mission briefing' , menuStrategicTargetsStrike , showStrategicTargetStrikeBriefing , nil)
    menuCommandStrategicTargetsSmokeGreenLocation = missionCommands.addCommandForCoalition(dispatcherCoalition , 'Green Smoke on location' , menuStrategicTargetsStrike , smokeStrategicTargetsStrikeLocation , SMOKECOLOR.Green)
    menuCommandStrategicTargetsSmokeOrangeLocation = missionCommands.addCommandForCoalition(dispatcherCoalition , 'Orange Smoke on location' , menuStrategicTargetsStrike , smokeStrategicTargetsStrikeLocation , SMOKECOLOR.Orange)
    menuCommandStrategicTargetsSmokeRedLocation = missionCommands.addCommandForCoalition(dispatcherCoalition , 'Red Smoke on location' , menuStrategicTargetsStrike , smokeStrategicTargetsStrikeLocation , SMOKECOLOR.Red)
    menuCommandStrategicTargetsSmokeWhiteLocation = missionCommands.addCommandForCoalition(dispatcherCoalition , 'White Smoke on location' , menuStrategicTargetsStrike , smokeStrategicTargetsStrikeLocation , SMOKECOLOR.White)
    menuCommandStrategicTargetsSmokeBlueLocation = missionCommands.addCommandForCoalition(dispatcherCoalition , 'Blue Smoke on location' , menuStrategicTargetsStrike , smokeStrategicTargetsStrikeLocation , SMOKECOLOR.Blue, strategicTargetPosition)
    menuCommandSkipChooseNextStrategicTarget = missionCommands.addCommandForCoalition(dispatcherCoalition , 'Skip to next strategic targets' , menuStrategicTargetsStrike , skipChooseNextStrategicTarget , 1)
  else
    trigger.action.outTextForCoalition(dispatcherCoalition,"NO STRATEGIC TARGET IN THE OPERATIONAL AREA ", 120)
    env.info("NO STRATEGIC TARGET IN THE OPERATIONAL AREA ")
  end
end

--startDispatcher()

env.info("STRATEGIC TARGET STRIKE_DISPATCHER LUA V1.0 File Loaded ... OK")
trigger.action.outText("STRATEGIC TARGET STRIKE_DISPATCHER LUA V1.0 File Loaded ... OK", 10)